/* phone-details-interface.c generated by valac 0.21.1.1-0d6f, the Vala compiler
 * generated from phone-details-interface.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <tracker-test.h>
#include <folks/folks.h>
#include <folks-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks-tracker.h>
#include <gio/gio.h>


#define TYPE_PHONE_DETAILS_INTERFACE_TESTS (phone_details_interface_tests_get_type ())
#define PHONE_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHONE_DETAILS_INTERFACE_TESTS, PhoneDetailsInterfaceTests))
#define PHONE_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHONE_DETAILS_INTERFACE_TESTS, PhoneDetailsInterfaceTestsClass))
#define IS_PHONE_DETAILS_INTERFACE_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHONE_DETAILS_INTERFACE_TESTS))
#define IS_PHONE_DETAILS_INTERFACE_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHONE_DETAILS_INTERFACE_TESTS))
#define PHONE_DETAILS_INTERFACE_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHONE_DETAILS_INTERFACE_TESTS, PhoneDetailsInterfaceTestsClass))

typedef struct _PhoneDetailsInterfaceTests PhoneDetailsInterfaceTests;
typedef struct _PhoneDetailsInterfaceTestsClass PhoneDetailsInterfaceTestsClass;
typedef struct _PhoneDetailsInterfaceTestsPrivate PhoneDetailsInterfaceTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _PhoneDetailsInterfaceTestsTestPhoneDetailsInterfaceAsyncData PhoneDetailsInterfaceTestsTestPhoneDetailsInterfaceAsyncData;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PhoneDetailsInterfaceTests {
	TrackerTestTestCase parent_instance;
	PhoneDetailsInterfaceTestsPrivate * priv;
};

struct _PhoneDetailsInterfaceTestsClass {
	TrackerTestTestCaseClass parent_class;
};

struct _PhoneDetailsInterfaceTestsPrivate {
	GMainLoop* _main_loop;
	FolksIndividualAggregator* _aggregator;
	gint _num_phones;
	gboolean _found_phone_1;
	gboolean _found_phone_2;
};

struct _PhoneDetailsInterfaceTestsTestPhoneDetailsInterfaceAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	PhoneDetailsInterfaceTests* self;
	FolksBackendStore* store;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};


static gpointer phone_details_interface_tests_parent_class = NULL;

GType phone_details_interface_tests_get_type (void) G_GNUC_CONST;
#define PHONE_DETAILS_INTERFACE_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PHONE_DETAILS_INTERFACE_TESTS, PhoneDetailsInterfaceTestsPrivate))
enum  {
	PHONE_DETAILS_INTERFACE_TESTS_DUMMY_PROPERTY
};
PhoneDetailsInterfaceTests* phone_details_interface_tests_new (void);
PhoneDetailsInterfaceTests* phone_details_interface_tests_construct (GType object_type);
void phone_details_interface_tests_test_phone_details_interface (PhoneDetailsInterfaceTests* self);
static void _phone_details_interface_tests_test_phone_details_interface_folks_test_case_test_method (gpointer self);
static void _phone_details_interface_tests_test_phone_details_interface_async (PhoneDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _phone_details_interface_tests_test_phone_details_interface_finish (PhoneDetailsInterfaceTests* self, GAsyncResult* _res_);
static void _phone_details_interface_tests_test_phone_details_interface_async_data_free (gpointer _data);
static gboolean _phone_details_interface_tests_test_phone_details_interface_async_co (PhoneDetailsInterfaceTestsTestPhoneDetailsInterfaceAsyncData* _data_);
static void _phone_details_interface_tests_test_phone_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _phone_details_interface_tests_individuals_changed_cb (PhoneDetailsInterfaceTests* self, GeeMultiMap* changes);
static void __phone_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void phone_details_interface_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _phone_details_interface_tests_test_phone_details_interface_folks_test_case_test_method (gpointer self) {
#line 38 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	phone_details_interface_tests_test_phone_details_interface (self);
#line 114 "phone-details-interface.c"
}


PhoneDetailsInterfaceTests* phone_details_interface_tests_construct (GType object_type) {
	PhoneDetailsInterfaceTests * self = NULL;
#line 36 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	self = (PhoneDetailsInterfaceTests*) tracker_test_test_case_construct (object_type, "PhoneDetailsInterfaceTests");
#line 38 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test phone details interface", _phone_details_interface_tests_test_phone_details_interface_folks_test_case_test_method, self);
#line 34 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	return self;
#line 126 "phone-details-interface.c"
}


PhoneDetailsInterfaceTests* phone_details_interface_tests_new (void) {
#line 34 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	return phone_details_interface_tests_construct (TYPE_PHONE_DETAILS_INTERFACE_TESTS);
#line 133 "phone-details-interface.c"
}


void phone_details_interface_tests_test_phone_details_interface (PhoneDetailsInterfaceTests* self) {
	GMainLoop* _tmp0_ = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	TrackerTestBackend* _tmp2_ = NULL;
	TrackerTestBackend* _tmp3_ = NULL;
	GMainLoop* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
#line 42 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 44 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 44 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 44 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	self->priv->_main_loop = _tmp0_;
#line 45 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 45 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	c1 = _tmp1_;
#line 47 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_FULLNAME, "persona #1");
#line 48 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	gee_abstract_map_set ((GeeAbstractMap*) c1, TRF_ONTOLOGY_DEFS_NCO_PHONE_PROP, "12345,54321");
#line 49 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp2_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 49 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	tracker_test_backend_add_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend), c1);
#line 51 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp3_ = ((TrackerTestTestCase*) self)->tracker_backend;
#line 51 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	tracker_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TRACKER_TEST_TYPE_BACKEND, TrackerTestBackend));
#line 53 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	self->priv->_num_phones = 0;
#line 54 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	self->priv->_found_phone_1 = FALSE;
#line 55 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	self->priv->_found_phone_2 = FALSE;
#line 57 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_phone_details_interface_tests_test_phone_details_interface_async (self, NULL, NULL);
#line 59 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp4_ = self->priv->_main_loop;
#line 59 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	folks_test_utils_loop_run_with_timeout (_tmp4_, 5);
#line 61 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp5_ = self->priv->_num_phones;
#line 61 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_vala_assert (_tmp5_ == 2, "this._num_phones == 2");
#line 62 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp6_ = self->priv->_found_phone_1;
#line 62 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_vala_assert (_tmp6_ == TRUE, "this._found_phone_1 == true");
#line 63 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp7_ = self->priv->_found_phone_2;
#line 63 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_vala_assert (_tmp7_ == TRUE, "this._found_phone_2 == true");
#line 42 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_g_object_unref0 (c1);
#line 197 "phone-details-interface.c"
}


static void _phone_details_interface_tests_test_phone_details_interface_async_data_free (gpointer _data) {
	PhoneDetailsInterfaceTestsTestPhoneDetailsInterfaceAsyncData* _data_;
	_data_ = _data;
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	g_slice_free (PhoneDetailsInterfaceTestsTestPhoneDetailsInterfaceAsyncData, _data_);
#line 208 "phone-details-interface.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	return self ? g_object_ref (self) : NULL;
#line 215 "phone-details-interface.c"
}


static void _phone_details_interface_tests_test_phone_details_interface_async (PhoneDetailsInterfaceTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	PhoneDetailsInterfaceTestsTestPhoneDetailsInterfaceAsyncData* _data_;
	PhoneDetailsInterfaceTests* _tmp0_ = NULL;
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_ = g_slice_new0 (PhoneDetailsInterfaceTestsTestPhoneDetailsInterfaceAsyncData);
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _phone_details_interface_tests_test_phone_details_interface_async);
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _phone_details_interface_tests_test_phone_details_interface_async_data_free);
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->self = _tmp0_;
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_phone_details_interface_tests_test_phone_details_interface_async_co (_data_);
#line 234 "phone-details-interface.c"
}


static void _phone_details_interface_tests_test_phone_details_interface_finish (PhoneDetailsInterfaceTests* self, GAsyncResult* _res_) {
	PhoneDetailsInterfaceTestsTestPhoneDetailsInterfaceAsyncData* _data_;
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 242 "phone-details-interface.c"
}


static void _phone_details_interface_tests_test_phone_details_interface_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	PhoneDetailsInterfaceTestsTestPhoneDetailsInterfaceAsyncData* _data_;
#line 69 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_ = _user_data_;
#line 69 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->_source_object_ = source_object;
#line 69 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->_res_ = _res_;
#line 69 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_phone_details_interface_tests_test_phone_details_interface_async_co (_data_);
#line 256 "phone-details-interface.c"
}


static void __phone_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 71 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_phone_details_interface_tests_individuals_changed_cb (self, changes);
#line 263 "phone-details-interface.c"
}


static gboolean _phone_details_interface_tests_test_phone_details_interface_async_co (PhoneDetailsInterfaceTestsTestPhoneDetailsInterfaceAsyncData* _data_) {
#line 66 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	switch (_data_->_state_) {
#line 66 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		case 0:
#line 272 "phone-details-interface.c"
		goto _state_0;
#line 66 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		case 1:
#line 276 "phone-details-interface.c"
		goto _state_1;
#line 66 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		case 2:
#line 280 "phone-details-interface.c"
		goto _state_2;
		default:
#line 66 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		g_assert_not_reached ();
#line 285 "phone-details-interface.c"
	}
	_state_0:
#line 68 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->_tmp0_ = NULL;
#line 68 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 68 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->store = _data_->_tmp0_;
#line 69 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->_state_ = 1;
#line 69 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	folks_backend_store_prepare (_data_->store, _phone_details_interface_tests_test_phone_details_interface_async_ready, _data_);
#line 69 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	return FALSE;
#line 300 "phone-details-interface.c"
	_state_1:
#line 69 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	folks_backend_store_prepare_finish (_data_->store, _data_->_res_);
#line 70 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->_tmp1_ = NULL;
#line 70 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 70 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 70 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 71 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->_tmp2_ = NULL;
#line 71 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 71 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __phone_details_interface_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 318 "phone-details-interface.c"
	{
#line 75 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_data_->_tmp3_ = NULL;
#line 75 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 75 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_data_->_state_ = 2;
#line 75 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _phone_details_interface_tests_test_phone_details_interface_async_ready, _data_);
#line 75 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		return FALSE;
#line 330 "phone-details-interface.c"
		_state_2:
#line 75 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 75 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		if (_data_->_inner_error_ != NULL) {
#line 336 "phone-details-interface.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 73 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_data_->e = _data_->_inner_error_;
#line 73 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_data_->_inner_error_ = NULL;
#line 79 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_data_->_tmp4_ = NULL;
#line 79 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_data_->_tmp4_ = _data_->e;
#line 79 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_data_->_tmp5_ = NULL;
#line 79 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 79 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		g_warning ("phone-details-interface.vala:79: Error when calling prepare: %s\n", _data_->_tmp5_);
#line 73 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_g_error_free0 (_data_->e);
#line 359 "phone-details-interface.c"
	}
	__finally0:
#line 73 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	if (_data_->_inner_error_ != NULL) {
#line 73 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_g_object_unref0 (_data_->store);
#line 73 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 73 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		g_clear_error (&_data_->_inner_error_);
#line 73 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		return FALSE;
#line 372 "phone-details-interface.c"
	}
#line 66 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_g_object_unref0 (_data_->store);
#line 66 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	if (_data_->_state_ == 0) {
#line 66 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 380 "phone-details-interface.c"
	} else {
#line 66 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 384 "phone-details-interface.c"
	}
#line 66 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	g_object_unref (_data_->_async_result);
#line 66 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	return FALSE;
#line 390 "phone-details-interface.c"
}


static void _phone_details_interface_tests_individuals_changed_cb (PhoneDetailsInterfaceTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gboolean _tmp36_ = FALSE;
	gboolean _tmp37_ = FALSE;
	gint _tmp38_ = 0;
	gboolean _tmp40_ = FALSE;
	gboolean _tmp42_ = FALSE;
	GeeSet* _tmp44_ = NULL;
	gint _tmp45_ = 0;
	gint _tmp46_ = 0;
#line 83 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	g_return_if_fail (self != NULL);
#line 83 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	g_return_if_fail (changes != NULL);
#line 86 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp0_ = changes;
#line 86 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 86 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	added = _tmp1_;
#line 87 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp2_ = changes;
#line 87 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 87 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	removed = _tmp3_;
#line 425 "phone-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_tmp4_ = added;
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_i_it = _tmp5_;
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		while (TRUE) {
#line 438 "phone-details-interface.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			gchar* full_name = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp6_ = _i_it;
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			if (!_tmp7_) {
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
				break;
#line 459 "phone-details-interface.c"
			}
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp8_ = _i_it;
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			i = (FolksIndividual*) _tmp9_;
#line 91 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp10_ = i;
#line 91 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 93 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp11_ = i;
#line 93 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp12_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp11_);
#line 93 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp13_ = _tmp12_;
#line 93 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp14_ = g_strdup (_tmp13_);
#line 93 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			full_name = _tmp14_;
#line 94 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp15_ = full_name;
#line 94 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			if (_tmp15_ != NULL) {
#line 485 "phone-details-interface.c"
				{
					GeeIterator* _phone_it = NULL;
					FolksIndividual* _tmp16_ = NULL;
					GeeSet* _tmp17_ = NULL;
					GeeSet* _tmp18_ = NULL;
					GeeIterator* _tmp19_ = NULL;
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
					_tmp16_ = i;
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
					_tmp17_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp16_);
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
					_tmp18_ = _tmp17_;
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
					_tmp19_ = gee_iterable_iterator ((GeeIterable*) _tmp18_);
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
					_phone_it = _tmp19_;
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
					while (TRUE) {
#line 504 "phone-details-interface.c"
						GeeIterator* _tmp20_ = NULL;
						gboolean _tmp21_ = FALSE;
						FolksPhoneFieldDetails* phone = NULL;
						GeeIterator* _tmp22_ = NULL;
						gpointer _tmp23_ = NULL;
						FolksPhoneFieldDetails* _tmp24_ = NULL;
						FolksPhoneFieldDetails* _tmp25_ = NULL;
						FolksPhoneFieldDetails* _tmp26_ = NULL;
						gboolean _tmp27_ = FALSE;
						gboolean _tmp28_ = FALSE;
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						_tmp20_ = _phone_it;
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						_tmp21_ = gee_iterator_next (_tmp20_);
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						if (!_tmp21_) {
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
							break;
#line 523 "phone-details-interface.c"
						}
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						_tmp22_ = _phone_it;
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						_tmp23_ = gee_iterator_get (_tmp22_);
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						phone = (FolksPhoneFieldDetails*) _tmp23_;
#line 98 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						_tmp24_ = phone;
#line 98 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						_tmp25_ = folks_phone_field_details_new ("12345", NULL);
#line 98 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						_tmp26_ = _tmp25_;
#line 98 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						_tmp27_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp24_, (FolksAbstractFieldDetails*) _tmp26_);
#line 98 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						_tmp28_ = _tmp27_;
#line 98 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						_g_object_unref0 (_tmp26_);
#line 98 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						if (_tmp28_) {
#line 545 "phone-details-interface.c"
							gint _tmp29_ = 0;
#line 100 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
							self->priv->_found_phone_1 = TRUE;
#line 101 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
							_tmp29_ = self->priv->_num_phones;
#line 101 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
							self->priv->_num_phones = _tmp29_ + 1;
#line 553 "phone-details-interface.c"
						} else {
							FolksPhoneFieldDetails* _tmp30_ = NULL;
							FolksPhoneFieldDetails* _tmp31_ = NULL;
							FolksPhoneFieldDetails* _tmp32_ = NULL;
							gboolean _tmp33_ = FALSE;
							gboolean _tmp34_ = FALSE;
#line 103 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
							_tmp30_ = phone;
#line 103 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
							_tmp31_ = folks_phone_field_details_new ("54321", NULL);
#line 103 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
							_tmp32_ = _tmp31_;
#line 103 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
							_tmp33_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp30_, (FolksAbstractFieldDetails*) _tmp32_);
#line 103 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
							_tmp34_ = _tmp33_;
#line 103 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
							_g_object_unref0 (_tmp32_);
#line 103 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
							if (_tmp34_) {
#line 574 "phone-details-interface.c"
								gint _tmp35_ = 0;
#line 105 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
								self->priv->_found_phone_2 = TRUE;
#line 106 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
								_tmp35_ = self->priv->_num_phones;
#line 106 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
								self->priv->_num_phones = _tmp35_ + 1;
#line 582 "phone-details-interface.c"
							}
						}
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
						_g_object_unref0 (phone);
#line 587 "phone-details-interface.c"
					}
#line 96 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
					_g_object_unref0 (_phone_it);
#line 591 "phone-details-interface.c"
				}
			}
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_g_free0 (full_name);
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_g_object_unref0 (i);
#line 598 "phone-details-interface.c"
		}
#line 89 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 602 "phone-details-interface.c"
	}
#line 112 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp38_ = self->priv->_num_phones;
#line 112 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	if (_tmp38_ == 2) {
#line 608 "phone-details-interface.c"
		gboolean _tmp39_ = FALSE;
#line 113 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_tmp39_ = self->priv->_found_phone_1;
#line 113 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_tmp37_ = _tmp39_ == TRUE;
#line 614 "phone-details-interface.c"
	} else {
#line 112 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_tmp37_ = FALSE;
#line 618 "phone-details-interface.c"
	}
#line 112 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp40_ = _tmp37_;
#line 112 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	if (_tmp40_) {
#line 624 "phone-details-interface.c"
		gboolean _tmp41_ = FALSE;
#line 114 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_tmp41_ = self->priv->_found_phone_2;
#line 114 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_tmp36_ = _tmp41_ == TRUE;
#line 630 "phone-details-interface.c"
	} else {
#line 112 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_tmp36_ = FALSE;
#line 634 "phone-details-interface.c"
	}
#line 112 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp42_ = _tmp36_;
#line 112 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	if (_tmp42_) {
#line 640 "phone-details-interface.c"
		GMainLoop* _tmp43_ = NULL;
#line 115 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_tmp43_ = self->priv->_main_loop;
#line 115 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		g_main_loop_quit (_tmp43_);
#line 646 "phone-details-interface.c"
	}
#line 117 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp44_ = removed;
#line 117 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp45_ = gee_collection_get_size ((GeeCollection*) _tmp44_);
#line 117 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp46_ = _tmp45_;
#line 117 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_vala_assert (_tmp46_ == 1, "removed.size == 1");
#line 656 "phone-details-interface.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp47_ = NULL;
		GeeIterator* _tmp48_ = NULL;
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_tmp47_ = removed;
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_tmp48_ = gee_iterable_iterator ((GeeIterable*) _tmp47_);
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_i_it = _tmp48_;
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		while (TRUE) {
#line 669 "phone-details-interface.c"
			GeeIterator* _tmp49_ = NULL;
			gboolean _tmp50_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp51_ = NULL;
			gpointer _tmp52_ = NULL;
			FolksIndividual* _tmp53_ = NULL;
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp49_ = _i_it;
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp50_ = gee_iterator_next (_tmp49_);
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			if (!_tmp50_) {
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
				break;
#line 684 "phone-details-interface.c"
			}
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp51_ = _i_it;
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp52_ = gee_iterator_get (_tmp51_);
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			i = (FolksIndividual*) _tmp52_;
#line 121 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_tmp53_ = i;
#line 121 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_vala_assert (_tmp53_ == NULL, "i == null");
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
			_g_object_unref0 (i);
#line 698 "phone-details-interface.c"
		}
#line 119 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
		_g_object_unref0 (_i_it);
#line 702 "phone-details-interface.c"
	}
#line 83 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_g_object_unref0 (removed);
#line 83 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_g_object_unref0 (added);
#line 708 "phone-details-interface.c"
}


static void phone_details_interface_tests_class_init (PhoneDetailsInterfaceTestsClass * klass) {
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	phone_details_interface_tests_parent_class = g_type_class_peek_parent (klass);
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	g_type_class_add_private (klass, sizeof (PhoneDetailsInterfaceTestsPrivate));
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	G_OBJECT_CLASS (klass)->finalize = phone_details_interface_tests_finalize;
#line 719 "phone-details-interface.c"
}


static void phone_details_interface_tests_instance_init (PhoneDetailsInterfaceTests * self) {
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	self->priv = PHONE_DETAILS_INTERFACE_TESTS_GET_PRIVATE (self);
#line 30 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	self->priv->_num_phones = 0;
#line 31 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	self->priv->_found_phone_1 = FALSE;
#line 32 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	self->priv->_found_phone_2 = FALSE;
#line 732 "phone-details-interface.c"
}


static void phone_details_interface_tests_finalize (GObject* obj) {
	PhoneDetailsInterfaceTests * self;
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PHONE_DETAILS_INTERFACE_TESTS, PhoneDetailsInterfaceTests);
#line 28 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 29 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 26 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	G_OBJECT_CLASS (phone_details_interface_tests_parent_class)->finalize (obj);
#line 746 "phone-details-interface.c"
}


GType phone_details_interface_tests_get_type (void) {
	static volatile gsize phone_details_interface_tests_type_id__volatile = 0;
	if (g_once_init_enter (&phone_details_interface_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhoneDetailsInterfaceTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) phone_details_interface_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhoneDetailsInterfaceTests), 0, (GInstanceInitFunc) phone_details_interface_tests_instance_init, NULL };
		GType phone_details_interface_tests_type_id;
		phone_details_interface_tests_type_id = g_type_register_static (TRACKER_TEST_TYPE_TEST_CASE, "PhoneDetailsInterfaceTests", &g_define_type_info, 0);
		g_once_init_leave (&phone_details_interface_tests_type_id__volatile, phone_details_interface_tests_type_id);
	}
	return phone_details_interface_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	PhoneDetailsInterfaceTests* tests = NULL;
	PhoneDetailsInterfaceTests* _tmp0_ = NULL;
#line 128 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	g_test_init (&args_length1, &args, NULL);
#line 130 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_tmp0_ = phone_details_interface_tests_new ();
#line 130 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	tests = _tmp0_;
#line 131 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 132 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	g_test_run ();
#line 133 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 135 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	result = 0;
#line 135 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	_g_object_unref0 (tests);
#line 135 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	return result;
#line 784 "phone-details-interface.c"
}


int main (int argc, char ** argv) {
#line 126 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	g_type_init ();
#line 126 "/home/treitter/collabora/folks/tests/tracker/phone-details-interface.vala"
	return _vala_main (argv, argc);
#line 793 "phone-details-interface.c"
}



