/* aggregation.c generated by valac 0.21.1.1-0d6f, the Vala compiler
 * generated from aggregation.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Travis Reitter <travis.reitter@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <tpf-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <tp-test-contactlist.h>
#include <folks/folks.h>
#include <kf-test.h>
#include <gio/gio.h>


#define TYPE_AGGREGATION_TESTS (aggregation_tests_get_type ())
#define AGGREGATION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AGGREGATION_TESTS, AggregationTests))
#define AGGREGATION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AGGREGATION_TESTS, AggregationTestsClass))
#define IS_AGGREGATION_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AGGREGATION_TESTS))
#define IS_AGGREGATION_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AGGREGATION_TESTS))
#define AGGREGATION_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AGGREGATION_TESTS, AggregationTestsClass))

typedef struct _AggregationTests AggregationTests;
typedef struct _AggregationTestsClass AggregationTestsClass;
typedef struct _AggregationTestsPrivate AggregationTestsPrivate;

#define AGGREGATION_TESTS_TYPE_INDIVIDUAL_STATE (aggregation_tests_individual_state_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
typedef struct _Block5Data Block5Data;
typedef struct _Block6Data Block6Data;
typedef struct _Block7Data Block7Data;
typedef struct _Block8Data Block8Data;
typedef struct _Block9Data Block9Data;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AggregationTests {
	TpfTestMixedTestCase parent_instance;
	AggregationTestsPrivate * priv;
};

struct _AggregationTestsClass {
	TpfTestMixedTestCaseClass parent_class;
};

struct _AggregationTestsPrivate {
	GeeHashSet* _default_personas;
};

typedef enum  {
	AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED,
	AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED,
	AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED
} AggregationTestsIndividualState;

struct _Block1Data {
	int _ref_count_;
	AggregationTests * self;
	GeeHashSet* default_individuals;
	GeeHashSet* expected_individuals;
	GeeHashSet* expected_individuals_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block2Data {
	int _ref_count_;
	AggregationTests * self;
	FolksIndividual* individual1;
	FolksIndividual* individual1_detailed;
	FolksIndividual* individual2;
	FolksIndividual* individual2_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block3Data {
	int _ref_count_;
	AggregationTests * self;
	FolksIndividual* individual1;
	FolksIndividual* individual1_detailed;
	FolksIndividual* individual2;
	FolksIndividual* individual2_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block4Data {
	int _ref_count_;
	AggregationTests * self;
	FolksIndividual* user_individual;
	FolksIndividual* user_individual_detailed;
	FolksIndividualAggregator* aggregator;
};

struct _Block5Data {
	int _ref_count_;
	AggregationTests * self;
	FolksIndividualAggregator* aggregator;
};

struct _Block6Data {
	int _ref_count_;
	AggregationTests * self;
	GeeHashMap* individuals_map;
	FolksIndividualAggregator* aggregator;
	gboolean aggregator_is_finalising;
};

struct _Block7Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	FolksIndividual* individual;
	FolksIndividualAggregator* aggregator;
	FolksPersona* writeable_persona;
};

struct _Block8Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	FolksIndividual* individual;
	FolksIndividualAggregator* aggregator;
	FolksPersona* writeable_persona;
};

struct _Block9Data {
	int _ref_count_;
	AggregationTests * self;
	GMainLoop* main_loop;
	FolksIndividual* individual;
	FolksIndividualAggregator* aggregator;
	FolksPersona* writeable_persona;
};


static gpointer aggregation_tests_parent_class = NULL;

GType aggregation_tests_get_type (void) G_GNUC_CONST;
#define AGGREGATION_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_AGGREGATION_TESTS, AggregationTestsPrivate))
enum  {
	AGGREGATION_TESTS_DUMMY_PROPERTY
};
static GType aggregation_tests_individual_state_get_type (void) G_GNUC_UNUSED;
AggregationTests* aggregation_tests_new (void);
AggregationTests* aggregation_tests_construct (GType object_type);
void aggregation_tests_test_iid (AggregationTests* self);
static void _aggregation_tests_test_iid_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_linkable_properties_same_store (AggregationTests* self);
static void _aggregation_tests_test_linkable_properties_same_store_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_linkable_properties_different_stores (AggregationTests* self);
static void _aggregation_tests_test_linkable_properties_different_stores_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_user (AggregationTests* self);
static void _aggregation_tests_test_user_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_untrusted_store (AggregationTests* self);
static void _aggregation_tests_test_untrusted_store_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_linked_individual_refcounting (AggregationTests* self);
static void _aggregation_tests_test_linked_individual_refcounting_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_ensure_individual_property_writeable_trivial (AggregationTests* self);
static void _aggregation_tests_test_ensure_individual_property_writeable_trivial_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_ensure_individual_property_writeable_add_persona (AggregationTests* self);
static void _aggregation_tests_test_ensure_individual_property_writeable_add_persona_folks_test_case_test_method (gpointer self);
void aggregation_tests_test_ensure_individual_property_writeable_failure (AggregationTests* self);
static void _aggregation_tests_test_ensure_individual_property_writeable_failure_folks_test_case_test_method (gpointer self);
static void aggregation_tests_real_set_up_tp (TpfTestTestCase* base);
static void aggregation_tests_real_set_up_kf (TpfTestTestCase* base);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda2_ (Block1Data* _data1_, GeeMultiMap* changes);
static void _aggregation_tests_test_iid_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, GeeSet* default_individuals, GeeSet* expected_individuals);
static void ___lambda2__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda3_ (Block1Data* _data1_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda3__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda4_ (Block1Data* _data1_);
static void __lambda5_ (Block1Data* _data1_, GObject* s, GAsyncResult* r);
static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda4__gsource_func (gpointer self);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void __lambda6_ (Block2Data* _data2_, GeeMultiMap* changes);
static void _aggregation_tests_test_linkable_properties_individuals_changed (AggregationTests* self, gboolean detailed, guint num_personas, GeeCollection* added, GeeSet* removed, FolksIndividual** individual1, FolksIndividual** individual2);
static void ___lambda6__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda7_ (Block2Data* _data2_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda7__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda8_ (Block2Data* _data2_);
static void __lambda9_ (Block2Data* _data2_, GObject* s, GAsyncResult* r);
static void ___lambda9__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda8__gsource_func (gpointer self);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void __lambda10_ (Block3Data* _data3_, GeeMultiMap* changes);
static void ___lambda10__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda11_ (Block3Data* _data3_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda11__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda12_ (Block3Data* _data3_);
static void __lambda13_ (Block3Data* _data3_, GObject* s, GAsyncResult* r);
static void ___lambda13__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda12__gsource_func (gpointer self);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static void __lambda14_ (Block4Data* _data4_, GeeMultiMap* changes);
static void _aggregation_tests_test_user_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, FolksIndividual** user_individual);
static void ___lambda14__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda15_ (Block4Data* _data4_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda15__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda16_ (Block4Data* _data4_);
static void __lambda17_ (Block4Data* _data4_, GObject* s, GAsyncResult* r);
static void ___lambda17__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda16__gsource_func (gpointer self);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void __lambda18_ (AggregationTests* self, GeeMultiMap* changes);
static void _aggregation_tests_test_untrusted_store_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed);
static void ___lambda18__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda19_ (AggregationTests* self, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ___lambda19__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda20_ (Block5Data* _data5_);
static void __lambda21_ (Block5Data* _data5_, GObject* s, GAsyncResult* r);
static void ___lambda21__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda20__gsource_func (gpointer self);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
static void __lambda22_ (Block6Data* _data6_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r);
static void ____lambda23_ (Block6Data* _data6_, GObject* obj);
static void _____lambda23__gweak_notify (gpointer self, GObject* object);
static void ___lambda22__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self);
static gboolean __lambda24_ (Block6Data* _data6_);
static void __lambda25_ (Block6Data* _data6_, GObject* s, GAsyncResult* r);
static void ___lambda25__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda24__gsource_func (gpointer self);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
static void __lambda26_ (Block7Data* _data7_, GeeMultiMap* changes);
static void ___lambda26__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda27_ (Block7Data* _data7_);
static void __lambda28_ (Block7Data* _data7_, GObject* s, GAsyncResult* r);
static void ___lambda28__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda27__gsource_func (gpointer self);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static gboolean __lambda29_ (Block7Data* _data7_);
static void __lambda30_ (Block7Data* _data7_, GObject* obj, GAsyncResult* res);
static void ___lambda30__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda29__gsource_func (gpointer self);
static Block8Data* block8_data_ref (Block8Data* _data8_);
static void block8_data_unref (void * _userdata_);
static void __lambda31_ (Block8Data* _data8_, GeeMultiMap* changes);
static void ___lambda31__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda32_ (Block8Data* _data8_);
static void __lambda33_ (Block8Data* _data8_, GObject* s, GAsyncResult* r);
static void ___lambda33__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda32__gsource_func (gpointer self);
static void __lambda34_ (Block8Data* _data8_, GeeMultiMap* changes);
static void ___lambda34__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda35_ (Block8Data* _data8_);
static void __lambda36_ (Block8Data* _data8_, GObject* obj, GAsyncResult* res);
static void ___lambda36__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda35__gsource_func (gpointer self);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
static void __lambda37_ (Block9Data* _data9_, GeeMultiMap* changes);
static void ___lambda37__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static gboolean __lambda38_ (Block9Data* _data9_);
static void __lambda39_ (Block9Data* _data9_, GObject* s, GAsyncResult* r);
static void ___lambda39__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda38__gsource_func (gpointer self);
static gboolean __lambda40_ (Block9Data* _data9_);
static void __lambda41_ (Block9Data* _data9_, GObject* obj, GAsyncResult* res);
static void ___lambda41__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ___lambda40__gsource_func (gpointer self);
static void aggregation_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static GType aggregation_tests_individual_state_get_type (void) {
	static volatile gsize aggregation_tests_individual_state_type_id__volatile = 0;
	if (g_once_init_enter (&aggregation_tests_individual_state_type_id__volatile)) {
		static const GEnumValue values[] = {{AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED, "AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED", "added"}, {AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED, "AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED", "removed"}, {AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED, "AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED", "finalised"}, {0, NULL, NULL}};
		GType aggregation_tests_individual_state_type_id;
		aggregation_tests_individual_state_type_id = g_enum_register_static ("AggregationTestsIndividualState", values);
		g_once_init_leave (&aggregation_tests_individual_state_type_id__volatile, aggregation_tests_individual_state_type_id);
	}
	return aggregation_tests_individual_state_type_id__volatile;
}


static void _aggregation_tests_test_iid_folks_test_case_test_method (gpointer self) {
#line 45 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_iid (self);
#line 314 "aggregation.c"
}


static void _aggregation_tests_test_linkable_properties_same_store_folks_test_case_test_method (gpointer self) {
#line 46 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_linkable_properties_same_store (self);
#line 321 "aggregation.c"
}


static void _aggregation_tests_test_linkable_properties_different_stores_folks_test_case_test_method (gpointer self) {
#line 48 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_linkable_properties_different_stores (self);
#line 328 "aggregation.c"
}


static void _aggregation_tests_test_user_folks_test_case_test_method (gpointer self) {
#line 50 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_user (self);
#line 335 "aggregation.c"
}


static void _aggregation_tests_test_untrusted_store_folks_test_case_test_method (gpointer self) {
#line 51 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_untrusted_store (self);
#line 342 "aggregation.c"
}


static void _aggregation_tests_test_linked_individual_refcounting_folks_test_case_test_method (gpointer self) {
#line 52 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_linked_individual_refcounting (self);
#line 349 "aggregation.c"
}


static void _aggregation_tests_test_ensure_individual_property_writeable_trivial_folks_test_case_test_method (gpointer self) {
#line 53 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_ensure_individual_property_writeable_trivial (self);
#line 356 "aggregation.c"
}


static void _aggregation_tests_test_ensure_individual_property_writeable_add_persona_folks_test_case_test_method (gpointer self) {
#line 55 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_ensure_individual_property_writeable_add_persona (self);
#line 363 "aggregation.c"
}


static void _aggregation_tests_test_ensure_individual_property_writeable_failure_folks_test_case_test_method (gpointer self) {
#line 57 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	aggregation_tests_test_ensure_individual_property_writeable_failure (self);
#line 370 "aggregation.c"
}


AggregationTests* aggregation_tests_construct (GType object_type) {
	AggregationTests * self = NULL;
	GeeHashSet* _tmp0_ = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeHashSet* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
	GeeHashSet* _tmp4_ = NULL;
	GeeHashSet* _tmp5_ = NULL;
	GeeHashSet* _tmp6_ = NULL;
	GeeHashSet* _tmp7_ = NULL;
	GeeHashSet* _tmp8_ = NULL;
#line 30 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = (AggregationTests*) tpf_test_mixed_test_case_construct (object_type, "Aggregation");
#line 33 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 33 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (self->priv->_default_personas);
#line 33 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self->priv->_default_personas = _tmp0_;
#line 35 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = self->priv->_default_personas;
#line 35 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp1_, "travis@example.com");
#line 36 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = self->priv->_default_personas;
#line 36 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp2_, "olivier@example.com");
#line 37 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = self->priv->_default_personas;
#line 37 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp3_, "guillaume@example.com");
#line 38 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp4_ = self->priv->_default_personas;
#line 38 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp4_, "sjoerd@example.com");
#line 39 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp5_ = self->priv->_default_personas;
#line 39 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, "christian@example.com");
#line 40 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp6_ = self->priv->_default_personas;
#line 40 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp6_, "wim@example.com");
#line 41 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp7_ = self->priv->_default_personas;
#line 41 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp7_, "helen@example.com");
#line 42 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp8_ = self->priv->_default_personas;
#line 42 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp8_, "geraldine@example.com");
#line 45 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "IID", _aggregation_tests_test_iid_folks_test_case_test_method, self);
#line 46 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "linkable properties:same store", _aggregation_tests_test_linkable_properties_same_store_folks_test_case_test_method, self);
#line 48 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "linkable properties:different stores", _aggregation_tests_test_linkable_properties_different_stores_folks_test_case_test_method, self);
#line 50 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "user", _aggregation_tests_test_user_folks_test_case_test_method, self);
#line 51 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "untrusted store", _aggregation_tests_test_untrusted_store_folks_test_case_test_method, self);
#line 52 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "refcounting", _aggregation_tests_test_linked_individual_refcounting_folks_test_case_test_method, self);
#line 53 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "ensure individual property writeable:trivial", _aggregation_tests_test_ensure_individual_property_writeable_trivial_folks_test_case_test_method, self);
#line 55 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "ensure individual property writeable:add persona", _aggregation_tests_test_ensure_individual_property_writeable_add_persona_folks_test_case_test_method, self);
#line 57 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "ensure individual property writeable:failure", _aggregation_tests_test_ensure_individual_property_writeable_failure_folks_test_case_test_method, self);
#line 28 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return self;
#line 445 "aggregation.c"
}


AggregationTests* aggregation_tests_new (void) {
#line 28 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return aggregation_tests_construct (TYPE_AGGREGATION_TESTS);
#line 452 "aggregation.c"
}


static void aggregation_tests_real_set_up_tp (TpfTestTestCase* base) {
	AggregationTests * self;
	TpTestsBackend* _tmp0_ = NULL;
#line 61 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = (AggregationTests*) base;
#line 64 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = ((TpfTestTestCase*) self)->tp_backend;
#line 64 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_tests_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, tp_tests_backend_get_type (), TpTestsBackend));
#line 465 "aggregation.c"
}


static void aggregation_tests_real_set_up_kf (TpfTestTestCase* base) {
	AggregationTests * self;
#line 67 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = (AggregationTests*) base;
#line 473 "aggregation.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return _data1_;
#line 482 "aggregation.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 491 "aggregation.c"
		AggregationTests * self;
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		self = _data1_->self;
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->aggregator);
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->expected_individuals_detailed);
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->expected_individuals);
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data1_->default_individuals);
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_slice_free (Block1Data, _data1_);
#line 507 "aggregation.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 83 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return self ? g_object_ref (self) : NULL;
#line 515 "aggregation.c"
}


static void __lambda2_ (Block1Data* _data1_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
	GeeHashSet* _tmp4_ = NULL;
	GeeHashSet* _tmp5_ = NULL;
#line 133 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 133 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 135 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 135 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 135 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 136 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 136 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 136 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 138 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp4_ = _data1_->default_individuals;
#line 138 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp5_ = _data1_->expected_individuals_detailed;
#line 138 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_iid_individuals_changed (self, TRUE, added, removed, (GeeSet*) _tmp4_, (GeeSet*) _tmp5_);
#line 133 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 133 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 555 "aggregation.c"
}


static void ___lambda2__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 133 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda2_ (self, changes);
#line 562 "aggregation.c"
}


static void __lambda3_ (Block1Data* _data1_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests * self;
	GeeSet* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeHashSet* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
#line 141 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 141 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 141 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 143 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 143 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 143 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = _data1_->default_individuals;
#line 143 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = _data1_->expected_individuals;
#line 143 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_iid_individuals_changed (self, FALSE, (GeeCollection*) _tmp0_, _tmp1_, (GeeSet*) _tmp2_, (GeeSet*) _tmp3_);
#line 588 "aggregation.c"
}


static void ___lambda3__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 141 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda3_ (self, added, removed, message, actor, reason);
#line 595 "aggregation.c"
}


static void __lambda5_ (Block1Data* _data1_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 606 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 157 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data1_->aggregator;
#line 157 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 157 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 157 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 618 "aggregation.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 155 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 155 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 161 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 161 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:161: Failed to prepare aggregator: %s", _tmp2_);
#line 163 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 155 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 639 "aggregation.c"
	}
	__finally0:
#line 155 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 155 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 155 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 155 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 650 "aggregation.c"
	}
}


static void ___lambda5__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda5_ (self, source_object, res);
#line 153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block1_data_unref (self);
#line 660 "aggregation.c"
}


static gboolean __lambda4_ (Block1Data* _data1_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 151 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data1_->self;
#line 153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data1_->aggregator;
#line 153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda5__gasync_ready_callback, block1_data_ref (_data1_));
#line 167 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 167 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 678 "aggregation.c"
}


static gboolean ___lambda4__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda4_ (self);
#line 151 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 687 "aggregation.c"
}


void aggregation_tests_test_iid (AggregationTests* self) {
	Block1Data* _data1_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	TpTestsBackend* tp_backend = NULL;
	TpTestsBackend* _tmp1_ = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	KfTestBackend* _tmp3_ = NULL;
	void* account1_handle = NULL;
	TpTestsBackend* _tmp4_ = NULL;
	void* _tmp5_ = NULL;
	void* account2_handle = NULL;
	TpTestsBackend* _tmp6_ = NULL;
	void* _tmp7_ = NULL;
	GeeHashSet* _tmp8_ = NULL;
	GeeHashSet* _tmp9_ = NULL;
	GeeHashSet* _tmp10_ = NULL;
	GeeHashSet* _tmp11_ = NULL;
	GeeHashSet* _tmp12_ = NULL;
	GeeHashSet* _tmp13_ = NULL;
	GeeHashSet* _tmp14_ = NULL;
	GeeHashSet* _tmp15_ = NULL;
	GeeHashSet* _tmp16_ = NULL;
	GeeHashSet* _tmp17_ = NULL;
	GeeHashSet* _tmp18_ = NULL;
	FolksIndividualAggregator* _tmp29_ = NULL;
	FolksIndividualAggregator* _tmp30_ = NULL;
	FolksIndividualAggregator* _tmp31_ = NULL;
	GMainLoop* _tmp32_ = NULL;
	GeeHashSet* _tmp33_ = NULL;
	gint _tmp34_ = 0;
	gint _tmp35_ = 0;
	GeeHashSet* _tmp36_ = NULL;
	gint _tmp37_ = 0;
	gint _tmp38_ = 0;
	TpTestsBackend* _tmp39_ = NULL;
	void* _tmp40_ = NULL;
	TpTestsBackend* _tmp41_ = NULL;
	void* _tmp42_ = NULL;
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data1_->_ref_count_ = 1;
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data1_->self = g_object_ref (self);
#line 81 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 81 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 83 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->tp_backend;
#line 83 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, tp_tests_backend_get_type (), TpTestsBackend));
#line 83 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_backend = _tmp2_;
#line 84 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = ((TpfTestTestCase*) self)->kf_backend;
#line 84 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, KF_TEST_TYPE_BACKEND, KfTestBackend), "");
#line 86 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp4_ = tp_backend;
#line 86 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_tests_backend_add_account (_tmp4_, "protocol", "me@example.com", "cm", "account");
#line 86 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp5_;
#line 88 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp6_ = tp_backend;
#line 88 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp7_ = tp_tests_backend_add_account (_tmp6_, "protocol", "me2@example.com", "cm", "account2");
#line 88 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp7_;
#line 100 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp8_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 100 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data1_->default_individuals = _tmp8_;
#line 103 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data1_->default_individuals;
#line 103 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp9_, "6380b17dc511b21a1defd4811f1add97b278f92c");
#line 105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp10_ = _data1_->default_individuals;
#line 105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp10_, "6b08188cb2ef8cbaca140b277780069b5af8add6");
#line 107 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp11_ = _data1_->default_individuals;
#line 107 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp11_, "60c91326018f6a60604f8d260fc24a60a5b8512c");
#line 109 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp12_ = _data1_->default_individuals;
#line 109 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp12_, "0e46c5e74f61908f49550d241f2a1651892a1695");
#line 111 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp13_ = _data1_->default_individuals;
#line 111 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp13_, "07b913b8977c04d2f2011e26a46ea3e3dcfe3e3d");
#line 113 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp14_ = _data1_->default_individuals;
#line 113 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp14_, "f948d4d2af79085ab860f0ef67bf0c201c4602d4");
#line 115 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp15_ = _data1_->default_individuals;
#line 115 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp15_, "f34529a442577b840a75271b464e90666c38c464");
#line 117 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp16_ = _data1_->default_individuals;
#line 117 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp16_, "467d13f955e62bf30ebf9620fa052aaee2160260");
#line 123 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp17_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 123 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data1_->expected_individuals = _tmp17_;
#line 124 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp18_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 124 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data1_->expected_individuals_detailed = _tmp18_;
#line 808 "aggregation.c"
	{
		GeeIterator* _id_it = NULL;
		GeeHashSet* _tmp19_ = NULL;
		GeeIterator* _tmp20_ = NULL;
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp19_ = _data1_->default_individuals;
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp20_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp19_);
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_id_it = _tmp20_;
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 821 "aggregation.c"
			GeeIterator* _tmp21_ = NULL;
			gboolean _tmp22_ = FALSE;
			gchar* id = NULL;
			GeeIterator* _tmp23_ = NULL;
			gpointer _tmp24_ = NULL;
			GeeHashSet* _tmp25_ = NULL;
			const gchar* _tmp26_ = NULL;
			GeeHashSet* _tmp27_ = NULL;
			const gchar* _tmp28_ = NULL;
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp21_ = _id_it;
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp22_ = gee_iterator_next (_tmp21_);
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp22_) {
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 839 "aggregation.c"
			}
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp23_ = _id_it;
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp24_ = gee_iterator_get (_tmp23_);
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			id = (gchar*) _tmp24_;
#line 127 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp25_ = _data1_->expected_individuals;
#line 127 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp26_ = id;
#line 127 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp25_, _tmp26_);
#line 128 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp27_ = _data1_->expected_individuals_detailed;
#line 128 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp28_ = id;
#line 128 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp27_, _tmp28_);
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_free0 (id);
#line 861 "aggregation.c"
		}
#line 125 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_id_it);
#line 865 "aggregation.c"
	}
#line 132 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp29_ = folks_individual_aggregator_dup ();
#line 132 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data1_->aggregator = _tmp29_;
#line 133 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp30_ = _data1_->aggregator;
#line 133 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp30_, "individuals-changed-detailed", (GCallback) ___lambda2__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 141 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp31_ = _data1_->aggregator;
#line 141 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp31_, "individuals-changed", (GCallback) ___lambda3__folks_individual_aggregator_individuals_changed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 151 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda4__gsource_func, block1_data_ref (_data1_), block1_data_unref);
#line 170 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp32_ = main_loop;
#line 170 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp32_, 3);
#line 173 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp33_ = _data1_->expected_individuals;
#line 173 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp34_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp33_);
#line 173 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp35_ = _tmp34_;
#line 173 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp35_ == 0, "expected_individuals.size == 0");
#line 174 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp36_ = _data1_->expected_individuals_detailed;
#line 174 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp37_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp36_);
#line 174 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp38_ = _tmp37_;
#line 174 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp38_ == 0, "expected_individuals_detailed.size == 0");
#line 177 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp39_ = tp_backend;
#line 177 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp40_ = account2_handle;
#line 177 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp39_, _tmp40_);
#line 178 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp41_ = tp_backend;
#line 178 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp42_ = account1_handle;
#line 178 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp41_, _tmp42_);
#line 179 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data1_->aggregator);
#line 179 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data1_->aggregator = NULL;
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (tp_backend);
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block1_data_unref (_data1_);
#line 79 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data1_ = NULL;
#line 925 "aggregation.c"
}


static void _aggregation_tests_test_iid_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, GeeSet* default_individuals, GeeSet* expected_individuals) {
#line 182 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 182 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 182 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 182 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (default_individuals != NULL);
#line 182 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (expected_individuals != NULL);
#line 940 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 953 "aggregation.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_ = NULL;
			gboolean _tmp9_ = FALSE;
			FolksIndividual* _tmp10_ = NULL;
			gboolean _tmp11_ = FALSE;
			gboolean _tmp12_ = FALSE;
			FolksIndividual* _tmp13_ = NULL;
			gboolean _tmp14_ = FALSE;
			gboolean _tmp15_ = FALSE;
			gboolean _tmp21_ = FALSE;
			gboolean _tmp27_ = FALSE;
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 978 "aggregation.c"
			}
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 190 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 190 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 190 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 992 "aggregation.c"
			} else {
				gboolean _tmp8_ = FALSE;
#line 190 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 190 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 999 "aggregation.c"
			}
#line 190 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp9_ = _tmp6_;
#line 190 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp9_, "i != null || detailed == true");
#line 191 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 191 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp10_ == NULL) {
#line 193 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 193 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				continue;
#line 1013 "aggregation.c"
			}
#line 196 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp13_ = i;
#line 196 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp14_ = folks_individual_get_is_user (_tmp13_);
#line 196 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp15_ = _tmp14_;
#line 196 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp15_) {
#line 1023 "aggregation.c"
				FolksIndividual* _tmp16_ = NULL;
				GeeSet* _tmp17_ = NULL;
				GeeSet* _tmp18_ = NULL;
				gint _tmp19_ = 0;
				gint _tmp20_ = 0;
#line 197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp16_ = i;
#line 197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp17_ = folks_individual_get_personas (_tmp16_);
#line 197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp18_ = _tmp17_;
#line 197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp19_ = gee_collection_get_size ((GeeCollection*) _tmp18_);
#line 197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp20_ = _tmp19_;
#line 197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp12_ = _tmp20_ == 2;
#line 1041 "aggregation.c"
			} else {
#line 196 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp12_ = FALSE;
#line 1045 "aggregation.c"
			}
#line 196 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp21_ = _tmp12_;
#line 196 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp21_) {
#line 1051 "aggregation.c"
				GeeSet* _tmp22_ = NULL;
				FolksIndividual* _tmp23_ = NULL;
				const gchar* _tmp24_ = NULL;
				const gchar* _tmp25_ = NULL;
				gboolean _tmp26_ = FALSE;
#line 198 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp22_ = default_individuals;
#line 198 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp23_ = i;
#line 198 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp24_ = folks_individual_get_id (_tmp23_);
#line 198 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp25_ = _tmp24_;
#line 198 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp26_ = gee_collection_contains ((GeeCollection*) _tmp22_, _tmp25_);
#line 198 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp11_ = _tmp26_;
#line 1069 "aggregation.c"
			} else {
#line 196 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp11_ = FALSE;
#line 1073 "aggregation.c"
			}
#line 196 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp27_ = _tmp11_;
#line 196 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp27_) {
#line 1079 "aggregation.c"
				GeeSet* _tmp28_ = NULL;
				FolksIndividual* _tmp29_ = NULL;
				const gchar* _tmp30_ = NULL;
				const gchar* _tmp31_ = NULL;
#line 200 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp28_ = expected_individuals;
#line 200 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp29_ = i;
#line 200 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp30_ = folks_individual_get_id (_tmp29_);
#line 200 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp31_ = _tmp30_;
#line 200 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				gee_collection_add ((GeeCollection*) _tmp28_, _tmp31_);
#line 1094 "aggregation.c"
			}
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 1098 "aggregation.c"
		}
#line 188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 1102 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp32_ = NULL;
		GeeIterator* _tmp33_ = NULL;
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp32_ = added;
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp33_ = gee_iterable_iterator ((GeeIterable*) _tmp32_);
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp33_;
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 1116 "aggregation.c"
			GeeIterator* _tmp34_ = NULL;
			gboolean _tmp35_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp36_ = NULL;
			gpointer _tmp37_ = NULL;
			gboolean _tmp38_ = FALSE;
			FolksIndividual* _tmp39_ = NULL;
			gboolean _tmp41_ = FALSE;
			FolksIndividual* _tmp42_ = NULL;
			GeeSet* personas = NULL;
			FolksIndividual* _tmp43_ = NULL;
			GeeSet* _tmp44_ = NULL;
			GeeSet* _tmp45_ = NULL;
			GeeSet* _tmp46_ = NULL;
			gboolean _tmp47_ = FALSE;
			FolksIndividual* _tmp48_ = NULL;
			gboolean _tmp49_ = FALSE;
			gboolean _tmp50_ = FALSE;
			gboolean _tmp54_ = FALSE;
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp34_ = _i_it;
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp35_ = gee_iterator_next (_tmp34_);
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp35_) {
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 1144 "aggregation.c"
			}
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp36_ = _i_it;
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp37_ = gee_iterator_get (_tmp36_);
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp37_;
#line 208 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp39_ = i;
#line 208 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp39_ != NULL) {
#line 208 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp38_ = TRUE;
#line 1158 "aggregation.c"
			} else {
				gboolean _tmp40_ = FALSE;
#line 208 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp40_ = detailed;
#line 208 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp38_ = _tmp40_ == TRUE;
#line 1165 "aggregation.c"
			}
#line 208 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp41_ = _tmp38_;
#line 208 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp41_, "i != null || detailed == true");
#line 209 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp42_ = i;
#line 209 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp42_ == NULL) {
#line 211 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 211 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				continue;
#line 1179 "aggregation.c"
			}
#line 214 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp43_ = i;
#line 214 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp44_ = folks_individual_get_personas (_tmp43_);
#line 214 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp45_ = _tmp44_;
#line 214 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp46_ = _g_object_ref0 (_tmp45_);
#line 214 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			personas = _tmp46_;
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp48_ = i;
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp49_ = folks_individual_get_is_user (_tmp48_);
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp50_ = _tmp49_;
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp50_) {
#line 1199 "aggregation.c"
				GeeSet* _tmp51_ = NULL;
				gint _tmp52_ = 0;
				gint _tmp53_ = 0;
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp51_ = personas;
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp52_ = gee_collection_get_size ((GeeCollection*) _tmp51_);
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp53_ = _tmp52_;
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp47_ = _tmp53_ == 2;
#line 1211 "aggregation.c"
			} else {
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp47_ = FALSE;
#line 1215 "aggregation.c"
			}
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp54_ = _tmp47_;
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp54_) {
#line 1221 "aggregation.c"
				GeeSet* _tmp55_ = NULL;
				FolksIndividual* _tmp56_ = NULL;
				const gchar* _tmp57_ = NULL;
				const gchar* _tmp58_ = NULL;
				gboolean _tmp59_ = FALSE;
				gchar* iid = NULL;
#line 219 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp55_ = expected_individuals;
#line 219 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp56_ = i;
#line 219 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp57_ = folks_individual_get_id (_tmp56_);
#line 219 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp58_ = _tmp57_;
#line 219 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp59_ = gee_collection_remove ((GeeCollection*) _tmp55_, _tmp58_);
#line 219 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_vala_assert (_tmp59_, "expected_individuals.remove (i.id)");
#line 221 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				iid = NULL;
#line 1242 "aggregation.c"
				{
					GeeIterator* _persona_it = NULL;
					GeeSet* _tmp60_ = NULL;
					GeeIterator* _tmp61_ = NULL;
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp60_ = personas;
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp61_ = gee_iterable_iterator ((GeeIterable*) _tmp60_);
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_persona_it = _tmp61_;
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					while (TRUE) {
#line 1255 "aggregation.c"
						GeeIterator* _tmp62_ = NULL;
						gboolean _tmp63_ = FALSE;
						FolksPersona* persona = NULL;
						GeeIterator* _tmp64_ = NULL;
						gpointer _tmp65_ = NULL;
						const gchar* _tmp66_ = NULL;
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp62_ = _persona_it;
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp63_ = gee_iterator_next (_tmp62_);
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						if (!_tmp63_) {
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							break;
#line 1270 "aggregation.c"
						}
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp64_ = _persona_it;
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp65_ = gee_iterator_get (_tmp64_);
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						persona = (FolksPersona*) _tmp65_;
#line 224 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp66_ = iid;
#line 224 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						if (_tmp66_ != NULL) {
#line 1282 "aggregation.c"
							FolksPersona* _tmp67_ = NULL;
							const gchar* _tmp68_ = NULL;
							const gchar* _tmp69_ = NULL;
							const gchar* _tmp70_ = NULL;
#line 226 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp67_ = persona;
#line 226 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp68_ = folks_persona_get_iid (_tmp67_);
#line 226 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp69_ = _tmp68_;
#line 226 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp70_ = iid;
#line 226 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_vala_assert (g_strcmp0 (_tmp69_, _tmp70_) == 0, "persona.iid == iid");
#line 1297 "aggregation.c"
						} else {
							FolksPersona* _tmp71_ = NULL;
							const gchar* _tmp72_ = NULL;
							const gchar* _tmp73_ = NULL;
							gchar* _tmp74_ = NULL;
#line 230 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp71_ = persona;
#line 230 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp72_ = folks_persona_get_iid (_tmp71_);
#line 230 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp73_ = _tmp72_;
#line 230 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp74_ = g_strdup (_tmp73_);
#line 230 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_g_free0 (iid);
#line 230 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							iid = _tmp74_;
#line 1315 "aggregation.c"
						}
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_g_object_unref0 (persona);
#line 1319 "aggregation.c"
					}
#line 222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (_persona_it);
#line 1323 "aggregation.c"
				}
#line 217 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_free0 (iid);
#line 1327 "aggregation.c"
			}
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (personas);
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 1333 "aggregation.c"
		}
#line 206 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 1337 "aggregation.c"
	}
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return _data2_;
#line 1347 "aggregation.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1356 "aggregation.c"
		AggregationTests * self;
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		self = _data2_->self;
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data2_->aggregator);
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_slice_free (Block2Data, _data2_);
#line 1366 "aggregation.c"
	}
}


static void __lambda6_ (Block2Data* _data2_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
#line 266 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 266 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 268 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 268 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 268 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 269 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 269 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 269 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 271 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, TRUE, (guint) 5, added, removed, &_data2_->individual1_detailed, &_data2_->individual2_detailed);
#line 266 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 266 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 1401 "aggregation.c"
}


static void ___lambda6__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 266 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda6_ (self, changes);
#line 1408 "aggregation.c"
}


static void __lambda7_ (Block2Data* _data2_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests * self;
	GeeSet* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 274 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 274 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 274 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 276 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 276 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 276 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, FALSE, (guint) 5, (GeeCollection*) _tmp0_, _tmp1_, &_data2_->individual1, &_data2_->individual2);
#line 1428 "aggregation.c"
}


static void ___lambda7__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 274 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda7_ (self, added, removed, message, actor, reason);
#line 1435 "aggregation.c"
}


static void __lambda9_ (Block2Data* _data2_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 286 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 286 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 1446 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 290 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data2_->aggregator;
#line 290 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 290 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 290 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 1458 "aggregation.c"
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 288 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 288 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 294 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 294 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:294: Failed to prepare aggregator: %s", _tmp2_);
#line 296 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 288 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 1479 "aggregation.c"
	}
	__finally1:
#line 288 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 288 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 288 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 288 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 1490 "aggregation.c"
	}
}


static void ___lambda9__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 286 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda9_ (self, source_object, res);
#line 286 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block2_data_unref (self);
#line 1500 "aggregation.c"
}


static gboolean __lambda8_ (Block2Data* _data2_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 284 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data2_->self;
#line 286 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data2_->aggregator;
#line 286 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda9__gasync_ready_callback, block2_data_ref (_data2_));
#line 300 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 300 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 1518 "aggregation.c"
}


static gboolean ___lambda8__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda8_ (self);
#line 284 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 1527 "aggregation.c"
}


void aggregation_tests_test_linkable_properties_same_store (AggregationTests* self) {
	Block2Data* _data2_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	void* _tmp3_ = NULL;
	FolksIndividualAggregator* _tmp4_ = NULL;
	FolksIndividualAggregator* _tmp5_ = NULL;
	FolksIndividualAggregator* _tmp6_ = NULL;
	GMainLoop* _tmp7_ = NULL;
	FolksIndividual* _tmp8_ = NULL;
	FolksIndividual* _tmp9_ = NULL;
	FolksIndividual* _tmp10_ = NULL;
	FolksIndividual* _tmp11_ = NULL;
	GeeHashSet* individual1_expected = NULL;
	GeeHashSet* _tmp12_ = NULL;
	GeeHashSet* _tmp13_ = NULL;
	GeeHashSet* _tmp14_ = NULL;
	GeeHashSet* _tmp15_ = NULL;
	GeeHashSet* _tmp16_ = NULL;
	GeeHashSet* _tmp17_ = NULL;
	GeeHashSet* individual2_expected = NULL;
	GeeHashSet* _tmp18_ = NULL;
	GeeHashSet* _tmp19_ = NULL;
	GeeHashSet* _tmp20_ = NULL;
	GeeHashSet* _tmp21_ = NULL;
	GeeHashSet* _tmp22_ = NULL;
	GeeHashSet* _tmp23_ = NULL;
	GeeHashSet* set_in_use = NULL;
	gboolean detailed_swapped = FALSE;
	GeeHashSet* _tmp86_ = NULL;
	gint _tmp87_ = 0;
	gint _tmp88_ = 0;
	GeeHashSet* _tmp89_ = NULL;
	GeeHashSet* _tmp90_ = NULL;
	GeeHashSet* _tmp123_ = NULL;
	gint _tmp124_ = 0;
	gint _tmp125_ = 0;
	TpTestsBackend* _tmp126_ = NULL;
	void* _tmp127_ = NULL;
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data2_->_ref_count_ = 1;
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data2_->self = g_object_ref (self);
#line 245 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 245 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 247 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 247 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "[0]\n" "protocol=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com\n" "[1]\n" "protocol=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com");
#line 254 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 254 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_tests_backend_add_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend), "protocol", "me@example.com", "cm", "account");
#line 254 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	((TpfTestTestCase*) self)->account_handle = _tmp3_;
#line 259 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data2_->individual1 = NULL;
#line 260 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data2_->individual1_detailed = NULL;
#line 261 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data2_->individual2 = NULL;
#line 262 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data2_->individual2_detailed = NULL;
#line 265 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp4_ = folks_individual_aggregator_dup ();
#line 265 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data2_->aggregator = _tmp4_;
#line 266 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp5_ = _data2_->aggregator;
#line 266 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp5_, "individuals-changed-detailed", (GCallback) ___lambda6__folks_individual_aggregator_individuals_changed_detailed, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 274 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp6_ = _data2_->aggregator;
#line 274 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp6_, "individuals-changed", (GCallback) ___lambda7__folks_individual_aggregator_individuals_changed, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 284 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda8__gsource_func, block2_data_ref (_data2_), block2_data_unref);
#line 303 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp7_ = main_loop;
#line 303 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp7_, 3);
#line 306 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp8_ = _data2_->individual1;
#line 306 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp8_ != NULL, "individual1 != null");
#line 307 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data2_->individual1_detailed;
#line 307 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp9_ != NULL, "individual1_detailed != null");
#line 308 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp10_ = _data2_->individual2;
#line 308 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp10_ != NULL, "individual2 != null");
#line 309 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp11_ = _data2_->individual2_detailed;
#line 309 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp11_ != NULL, "individual2_detailed != null");
#line 311 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp12_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 311 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	individual1_expected = _tmp12_;
#line 312 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp13_ = individual1_expected;
#line 312 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp13_, "0");
#line 313 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp14_ = individual1_expected;
#line 313 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp14_, "travis@example.com");
#line 314 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp15_ = individual1_expected;
#line 314 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp15_, "olivier@example.com");
#line 315 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp16_ = individual1_expected;
#line 315 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp16_, "guillaume@example.com");
#line 316 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp17_ = individual1_expected;
#line 316 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp17_, "sjoerd@example.com");
#line 318 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp18_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 318 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	individual2_expected = _tmp18_;
#line 319 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp19_ = individual2_expected;
#line 319 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp19_, "1");
#line 320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp20_ = individual2_expected;
#line 320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp20_, "christian@example.com");
#line 321 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp21_ = individual2_expected;
#line 321 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp21_, "wim@example.com");
#line 322 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp22_ = individual2_expected;
#line 322 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp22_, "helen@example.com");
#line 323 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp23_ = individual2_expected;
#line 323 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp23_, "geraldine@example.com");
#line 325 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	set_in_use = NULL;
#line 326 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	detailed_swapped = FALSE;
#line 1688 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp24_ = NULL;
		GeeSet* _tmp25_ = NULL;
		GeeSet* _tmp26_ = NULL;
		GeeIterator* _tmp27_ = NULL;
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp24_ = _data2_->individual1;
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp25_ = folks_individual_get_personas (_tmp24_);
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp26_ = _tmp25_;
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp27_ = gee_iterable_iterator ((GeeIterable*) _tmp26_);
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_p_it = _tmp27_;
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 1707 "aggregation.c"
			GeeIterator* _tmp28_ = NULL;
			gboolean _tmp29_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp30_ = NULL;
			gpointer _tmp31_ = NULL;
			gboolean _tmp32_ = FALSE;
			GeeHashSet* _tmp33_ = NULL;
			gboolean _tmp39_ = FALSE;
			GeeHashSet* _tmp45_ = NULL;
			FolksPersona* _tmp46_ = NULL;
			const gchar* _tmp47_ = NULL;
			const gchar* _tmp48_ = NULL;
			gboolean _tmp49_ = FALSE;
			gboolean found_detailed = FALSE;
			gboolean _tmp64_ = FALSE;
			gboolean _tmp65_ = FALSE;
			gboolean _tmp67_ = FALSE;
			gboolean _tmp85_ = FALSE;
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp28_ = _p_it;
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp29_ = gee_iterator_next (_tmp28_);
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp29_) {
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 1734 "aggregation.c"
			}
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp30_ = _p_it;
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp31_ = gee_iterator_get (_tmp30_);
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp31_;
#line 330 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp33_ = set_in_use;
#line 330 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp33_ == NULL) {
#line 1746 "aggregation.c"
				GeeHashSet* _tmp34_ = NULL;
				FolksPersona* _tmp35_ = NULL;
				const gchar* _tmp36_ = NULL;
				const gchar* _tmp37_ = NULL;
				gboolean _tmp38_ = FALSE;
#line 331 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp34_ = individual1_expected;
#line 331 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp35_ = p;
#line 331 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp36_ = folks_persona_get_display_id (_tmp35_);
#line 331 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp37_ = _tmp36_;
#line 331 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp38_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp34_, _tmp37_);
#line 331 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp32_ = _tmp38_;
#line 1764 "aggregation.c"
			} else {
#line 330 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp32_ = FALSE;
#line 1768 "aggregation.c"
			}
#line 330 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp39_ = _tmp32_;
#line 330 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp39_) {
#line 1774 "aggregation.c"
				GeeHashSet* _tmp40_ = NULL;
				GeeHashSet* _tmp41_ = NULL;
#line 333 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp40_ = individual1_expected;
#line 333 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp41_ = _g_object_ref0 (_tmp40_);
#line 333 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (set_in_use);
#line 333 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				set_in_use = _tmp41_;
#line 1785 "aggregation.c"
			} else {
				GeeHashSet* _tmp42_ = NULL;
#line 335 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp42_ = set_in_use;
#line 335 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				if (_tmp42_ == NULL) {
#line 1792 "aggregation.c"
					GeeHashSet* _tmp43_ = NULL;
					GeeHashSet* _tmp44_ = NULL;
#line 337 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp43_ = individual2_expected;
#line 337 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp44_ = _g_object_ref0 (_tmp43_);
#line 337 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (set_in_use);
#line 337 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					set_in_use = _tmp44_;
#line 1803 "aggregation.c"
				}
			}
#line 340 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp45_ = set_in_use;
#line 340 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp46_ = p;
#line 340 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp47_ = folks_persona_get_display_id (_tmp46_);
#line 340 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp48_ = _tmp47_;
#line 340 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp49_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp45_, _tmp48_);
#line 340 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp49_, "set_in_use.remove (p.display_id)");
#line 342 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			found_detailed = FALSE;
#line 1820 "aggregation.c"
			{
				GeeIterator* _pd_it = NULL;
				FolksIndividual* _tmp50_ = NULL;
				GeeSet* _tmp51_ = NULL;
				GeeSet* _tmp52_ = NULL;
				GeeIterator* _tmp53_ = NULL;
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp50_ = _data2_->individual1_detailed;
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp51_ = folks_individual_get_personas (_tmp50_);
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp52_ = _tmp51_;
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp53_ = gee_iterable_iterator ((GeeIterable*) _tmp52_);
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_pd_it = _tmp53_;
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 1839 "aggregation.c"
					GeeIterator* _tmp54_ = NULL;
					gboolean _tmp55_ = FALSE;
					FolksPersona* pd = NULL;
					GeeIterator* _tmp56_ = NULL;
					gpointer _tmp57_ = NULL;
					FolksPersona* _tmp58_ = NULL;
					const gchar* _tmp59_ = NULL;
					const gchar* _tmp60_ = NULL;
					FolksPersona* _tmp61_ = NULL;
					const gchar* _tmp62_ = NULL;
					const gchar* _tmp63_ = NULL;
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp54_ = _pd_it;
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp55_ = gee_iterator_next (_tmp54_);
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					if (!_tmp55_) {
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						break;
#line 1859 "aggregation.c"
					}
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp56_ = _pd_it;
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp57_ = gee_iterator_get (_tmp56_);
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					pd = (FolksPersona*) _tmp57_;
#line 345 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp58_ = pd;
#line 345 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp59_ = folks_persona_get_uid (_tmp58_);
#line 345 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp60_ = _tmp59_;
#line 345 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp61_ = p;
#line 345 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp62_ = folks_persona_get_uid (_tmp61_);
#line 345 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp63_ = _tmp62_;
#line 345 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					if (g_strcmp0 (_tmp60_, _tmp63_) == 0) {
#line 347 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						found_detailed = TRUE;
#line 1883 "aggregation.c"
					}
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (pd);
#line 1887 "aggregation.c"
				}
#line 343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_pd_it);
#line 1891 "aggregation.c"
			}
#line 351 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp65_ = found_detailed;
#line 351 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp65_) {
#line 1897 "aggregation.c"
				gboolean _tmp66_ = FALSE;
#line 351 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp66_ = detailed_swapped;
#line 351 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp64_ = !_tmp66_;
#line 1903 "aggregation.c"
			} else {
#line 351 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp64_ = FALSE;
#line 1907 "aggregation.c"
			}
#line 351 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp67_ = _tmp64_;
#line 351 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp67_) {
#line 1913 "aggregation.c"
				FolksIndividual* tmp = NULL;
				FolksIndividual* _tmp68_ = NULL;
				FolksIndividual* _tmp69_ = NULL;
				FolksIndividual* _tmp70_ = NULL;
#line 355 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp68_ = _data2_->individual1_detailed;
#line 355 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				tmp = _tmp68_;
#line 356 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp69_ = _data2_->individual2_detailed;
#line 356 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_data2_->individual1_detailed = _tmp69_;
#line 357 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp70_ = tmp;
#line 357 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_data2_->individual2_detailed = _tmp70_;
#line 358 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				detailed_swapped = TRUE;
#line 1932 "aggregation.c"
				{
					GeeIterator* _pd_it = NULL;
					FolksIndividual* _tmp71_ = NULL;
					GeeSet* _tmp72_ = NULL;
					GeeSet* _tmp73_ = NULL;
					GeeIterator* _tmp74_ = NULL;
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp71_ = _data2_->individual1_detailed;
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp72_ = folks_individual_get_personas (_tmp71_);
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp73_ = _tmp72_;
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp74_ = gee_iterable_iterator ((GeeIterable*) _tmp73_);
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_pd_it = _tmp74_;
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					while (TRUE) {
#line 1951 "aggregation.c"
						GeeIterator* _tmp75_ = NULL;
						gboolean _tmp76_ = FALSE;
						FolksPersona* pd = NULL;
						GeeIterator* _tmp77_ = NULL;
						gpointer _tmp78_ = NULL;
						FolksPersona* _tmp79_ = NULL;
						const gchar* _tmp80_ = NULL;
						const gchar* _tmp81_ = NULL;
						FolksPersona* _tmp82_ = NULL;
						const gchar* _tmp83_ = NULL;
						const gchar* _tmp84_ = NULL;
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp75_ = _pd_it;
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp76_ = gee_iterator_next (_tmp75_);
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						if (!_tmp76_) {
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							break;
#line 1971 "aggregation.c"
						}
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp77_ = _pd_it;
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp78_ = gee_iterator_get (_tmp77_);
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						pd = (FolksPersona*) _tmp78_;
#line 362 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp79_ = pd;
#line 362 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp80_ = folks_persona_get_uid (_tmp79_);
#line 362 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp81_ = _tmp80_;
#line 362 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp82_ = p;
#line 362 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp83_ = folks_persona_get_uid (_tmp82_);
#line 362 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp84_ = _tmp83_;
#line 362 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						if (g_strcmp0 (_tmp81_, _tmp84_) == 0) {
#line 364 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							found_detailed = TRUE;
#line 1995 "aggregation.c"
						}
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_g_object_unref0 (pd);
#line 1999 "aggregation.c"
					}
#line 360 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (_pd_it);
#line 2003 "aggregation.c"
				}
			}
#line 369 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp85_ = found_detailed;
#line 369 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp85_ == TRUE, "found_detailed == true");
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2012 "aggregation.c"
		}
#line 327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2016 "aggregation.c"
	}
#line 372 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp86_ = set_in_use;
#line 372 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp87_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp86_);
#line 372 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp88_ = _tmp87_;
#line 372 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp88_ == 0, "set_in_use.size == 0");
#line 374 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp89_ = set_in_use;
#line 374 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp90_ = individual1_expected;
#line 374 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_tmp89_ == _tmp90_) {
#line 2032 "aggregation.c"
		GeeHashSet* _tmp91_ = NULL;
		GeeHashSet* _tmp92_ = NULL;
#line 376 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp91_ = individual2_expected;
#line 376 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp92_ = _g_object_ref0 (_tmp91_);
#line 376 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (set_in_use);
#line 376 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		set_in_use = _tmp92_;
#line 2043 "aggregation.c"
	} else {
		GeeHashSet* _tmp93_ = NULL;
		GeeHashSet* _tmp94_ = NULL;
#line 380 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp93_ = individual1_expected;
#line 380 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp94_ = _g_object_ref0 (_tmp93_);
#line 380 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (set_in_use);
#line 380 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		set_in_use = _tmp94_;
#line 2055 "aggregation.c"
	}
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp95_ = NULL;
		GeeSet* _tmp96_ = NULL;
		GeeSet* _tmp97_ = NULL;
		GeeIterator* _tmp98_ = NULL;
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp95_ = _data2_->individual2;
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp96_ = folks_individual_get_personas (_tmp95_);
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp97_ = _tmp96_;
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp98_ = gee_iterable_iterator ((GeeIterable*) _tmp97_);
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_p_it = _tmp98_;
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2075 "aggregation.c"
			GeeIterator* _tmp99_ = NULL;
			gboolean _tmp100_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp101_ = NULL;
			gpointer _tmp102_ = NULL;
			GeeHashSet* _tmp103_ = NULL;
			FolksPersona* _tmp104_ = NULL;
			const gchar* _tmp105_ = NULL;
			const gchar* _tmp106_ = NULL;
			gboolean _tmp107_ = FALSE;
			gboolean found_detailed = FALSE;
			gboolean _tmp122_ = FALSE;
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp99_ = _p_it;
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp100_ = gee_iterator_next (_tmp99_);
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp100_) {
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 2096 "aggregation.c"
			}
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp101_ = _p_it;
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp102_ = gee_iterator_get (_tmp101_);
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp102_;
#line 385 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp103_ = set_in_use;
#line 385 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp104_ = p;
#line 385 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp105_ = folks_persona_get_display_id (_tmp104_);
#line 385 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp106_ = _tmp105_;
#line 385 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp107_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp103_, _tmp106_);
#line 385 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp107_, "set_in_use.remove (p.display_id)");
#line 387 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			found_detailed = FALSE;
#line 2118 "aggregation.c"
			{
				GeeIterator* _pd_it = NULL;
				FolksIndividual* _tmp108_ = NULL;
				GeeSet* _tmp109_ = NULL;
				GeeSet* _tmp110_ = NULL;
				GeeIterator* _tmp111_ = NULL;
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp108_ = _data2_->individual2_detailed;
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp109_ = folks_individual_get_personas (_tmp108_);
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp110_ = _tmp109_;
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp111_ = gee_iterable_iterator ((GeeIterable*) _tmp110_);
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_pd_it = _tmp111_;
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 2137 "aggregation.c"
					GeeIterator* _tmp112_ = NULL;
					gboolean _tmp113_ = FALSE;
					FolksPersona* pd = NULL;
					GeeIterator* _tmp114_ = NULL;
					gpointer _tmp115_ = NULL;
					FolksPersona* _tmp116_ = NULL;
					const gchar* _tmp117_ = NULL;
					const gchar* _tmp118_ = NULL;
					FolksPersona* _tmp119_ = NULL;
					const gchar* _tmp120_ = NULL;
					const gchar* _tmp121_ = NULL;
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp112_ = _pd_it;
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp113_ = gee_iterator_next (_tmp112_);
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					if (!_tmp113_) {
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						break;
#line 2157 "aggregation.c"
					}
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp114_ = _pd_it;
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp115_ = gee_iterator_get (_tmp114_);
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					pd = (FolksPersona*) _tmp115_;
#line 390 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp116_ = pd;
#line 390 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp117_ = folks_persona_get_uid (_tmp116_);
#line 390 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp118_ = _tmp117_;
#line 390 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp119_ = p;
#line 390 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp120_ = folks_persona_get_uid (_tmp119_);
#line 390 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp121_ = _tmp120_;
#line 390 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					if (g_strcmp0 (_tmp118_, _tmp121_) == 0) {
#line 392 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						found_detailed = TRUE;
#line 2181 "aggregation.c"
					}
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (pd);
#line 2185 "aggregation.c"
				}
#line 388 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_pd_it);
#line 2189 "aggregation.c"
			}
#line 395 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp122_ = found_detailed;
#line 395 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp122_ == TRUE, "found_detailed == true");
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2197 "aggregation.c"
		}
#line 383 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2201 "aggregation.c"
	}
#line 398 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp123_ = set_in_use;
#line 398 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp124_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp123_);
#line 398 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp125_ = _tmp124_;
#line 398 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp125_ == 0, "set_in_use.size == 0");
#line 401 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp126_ = ((TpfTestTestCase*) self)->tp_backend;
#line 401 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp127_ = ((TpfTestTestCase*) self)->account_handle;
#line 401 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp126_, tp_tests_backend_get_type (), TpTestsBackend), (void*) _tmp127_);
#line 402 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data2_->aggregator);
#line 402 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data2_->aggregator = NULL;
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (set_in_use);
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (individual2_expected);
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (individual1_expected);
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block2_data_unref (_data2_);
#line 243 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data2_ = NULL;
#line 2233 "aggregation.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return _data3_;
#line 2242 "aggregation.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 2251 "aggregation.c"
		AggregationTests * self;
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		self = _data3_->self;
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data3_->aggregator);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_slice_free (Block3Data, _data3_);
#line 2261 "aggregation.c"
	}
}


static void __lambda10_ (Block3Data* _data3_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
#line 442 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 442 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 444 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 444 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 444 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 445 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 445 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 445 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 447 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, TRUE, (guint) 9, added, removed, &_data3_->individual1_detailed, &_data3_->individual2_detailed);
#line 442 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 442 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 2296 "aggregation.c"
}


static void ___lambda10__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 442 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda10_ (self, changes);
#line 2303 "aggregation.c"
}


static void __lambda11_ (Block3Data* _data3_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests * self;
	GeeSet* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 450 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 450 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 450 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 452 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 452 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 452 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_linkable_properties_individuals_changed (self, FALSE, (guint) 9, (GeeCollection*) _tmp0_, _tmp1_, &_data3_->individual1, &_data3_->individual2);
#line 2323 "aggregation.c"
}


static void ___lambda11__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 450 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda11_ (self, added, removed, message, actor, reason);
#line 2330 "aggregation.c"
}


static void __lambda13_ (Block3Data* _data3_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 462 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 462 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 2341 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 466 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data3_->aggregator;
#line 466 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 466 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 466 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 2353 "aggregation.c"
			goto __catch2_g_error;
		}
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 464 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 464 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 470 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 470 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:470: Failed to prepare aggregator: %s", _tmp2_);
#line 472 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 464 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 2374 "aggregation.c"
	}
	__finally2:
#line 464 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 464 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 464 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 464 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 2385 "aggregation.c"
	}
}


static void ___lambda13__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 462 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda13_ (self, source_object, res);
#line 462 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block3_data_unref (self);
#line 2395 "aggregation.c"
}


static gboolean __lambda12_ (Block3Data* _data3_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 460 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data3_->self;
#line 462 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data3_->aggregator;
#line 462 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda13__gasync_ready_callback, block3_data_ref (_data3_));
#line 476 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 476 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 2413 "aggregation.c"
}


static gboolean ___lambda12__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda12_ (self);
#line 460 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 2422 "aggregation.c"
}


void aggregation_tests_test_linkable_properties_different_stores (AggregationTests* self) {
	Block3Data* _data3_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* tp_backend = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	TpTestsBackend* _tmp3_ = NULL;
	void* account1_handle = NULL;
	TpTestsBackend* _tmp4_ = NULL;
	void* _tmp5_ = NULL;
	void* account2_handle = NULL;
	TpTestsBackend* _tmp6_ = NULL;
	void* _tmp7_ = NULL;
	FolksIndividualAggregator* _tmp8_ = NULL;
	FolksIndividualAggregator* _tmp9_ = NULL;
	FolksIndividualAggregator* _tmp10_ = NULL;
	GMainLoop* _tmp11_ = NULL;
	FolksIndividual* _tmp12_ = NULL;
	FolksIndividual* _tmp13_ = NULL;
	FolksIndividual* _tmp14_ = NULL;
	FolksIndividual* _tmp15_ = NULL;
	GeeHashSet* expected_personas1 = NULL;
	GeeHashSet* _tmp16_ = NULL;
	GeeHashSet* expected_personas1_detailed = NULL;
	GeeHashSet* _tmp17_ = NULL;
	GeeHashSet* expected_personas2 = NULL;
	GeeHashSet* _tmp18_ = NULL;
	GeeHashSet* expected_personas2_detailed = NULL;
	GeeHashSet* _tmp19_ = NULL;
	GeeHashSet* _tmp57_ = NULL;
	gint _tmp58_ = 0;
	gint _tmp59_ = 0;
	GeeHashSet* _tmp83_ = NULL;
	gint _tmp84_ = 0;
	gint _tmp85_ = 0;
	GeeHashSet* _tmp109_ = NULL;
	gint _tmp110_ = 0;
	gint _tmp111_ = 0;
	GeeHashSet* _tmp135_ = NULL;
	gint _tmp136_ = 0;
	gint _tmp137_ = 0;
	TpTestsBackend* _tmp138_ = NULL;
	void* _tmp139_ = NULL;
	TpTestsBackend* _tmp140_ = NULL;
	void* _tmp141_ = NULL;
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data3_->_ref_count_ = 1;
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data3_->self = g_object_ref (self);
#line 414 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 414 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 416 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 416 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "[0]\n" "protocol=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com\n" "protocol2=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com\n" "[1]\n" "protocol=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com\n" "protocol2=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com");
#line 427 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 427 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend));
#line 427 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_backend = _tmp3_;
#line 428 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp4_ = tp_backend;
#line 428 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_tests_backend_add_account (_tmp4_, "protocol", "me@example.com", "cm", "account");
#line 428 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp5_;
#line 430 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp6_ = tp_backend;
#line 430 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp7_ = tp_tests_backend_add_account (_tmp6_, "protocol2", "me@example.com", "cm", "account2");
#line 430 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp7_;
#line 435 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data3_->individual1 = NULL;
#line 436 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data3_->individual1_detailed = NULL;
#line 437 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data3_->individual2 = NULL;
#line 438 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data3_->individual2_detailed = NULL;
#line 441 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp8_ = folks_individual_aggregator_dup ();
#line 441 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data3_->aggregator = _tmp8_;
#line 442 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data3_->aggregator;
#line 442 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp9_, "individuals-changed-detailed", (GCallback) ___lambda10__folks_individual_aggregator_individuals_changed_detailed, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 450 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp10_ = _data3_->aggregator;
#line 450 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp10_, "individuals-changed", (GCallback) ___lambda11__folks_individual_aggregator_individuals_changed, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 460 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda12__gsource_func, block3_data_ref (_data3_), block3_data_unref);
#line 479 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp11_ = main_loop;
#line 479 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp11_, 3);
#line 482 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp12_ = _data3_->individual1;
#line 482 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp12_ != NULL, "individual1 != null");
#line 483 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp13_ = _data3_->individual1_detailed;
#line 483 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp13_ != NULL, "individual1_detailed != null");
#line 484 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp14_ = _data3_->individual2;
#line 484 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp14_ != NULL, "individual2 != null");
#line 485 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp15_ = _data3_->individual2_detailed;
#line 485 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp15_ != NULL, "individual2_detailed != null");
#line 491 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp16_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 491 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	expected_personas1 = _tmp16_;
#line 492 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp17_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 492 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	expected_personas1_detailed = _tmp17_;
#line 493 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp18_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 493 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	expected_personas2 = _tmp18_;
#line 494 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp19_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 494 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	expected_personas2_detailed = _tmp19_;
#line 2564 "aggregation.c"
	{
		GeeIterator* _id_it = NULL;
		GeeHashSet* _tmp20_ = NULL;
		GeeIterator* _tmp21_ = NULL;
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp20_ = self->priv->_default_personas;
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp21_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp20_);
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_id_it = _tmp21_;
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2577 "aggregation.c"
			GeeIterator* _tmp22_ = NULL;
			gboolean _tmp23_ = FALSE;
			gchar* id = NULL;
			GeeIterator* _tmp24_ = NULL;
			gpointer _tmp25_ = NULL;
			GeeHashSet* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
			GeeHashSet* _tmp28_ = NULL;
			const gchar* _tmp29_ = NULL;
			GeeHashSet* _tmp30_ = NULL;
			const gchar* _tmp31_ = NULL;
			GeeHashSet* _tmp32_ = NULL;
			const gchar* _tmp33_ = NULL;
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp22_ = _id_it;
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp23_ = gee_iterator_next (_tmp22_);
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp23_) {
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 2599 "aggregation.c"
			}
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp24_ = _id_it;
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp25_ = gee_iterator_get (_tmp24_);
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			id = (gchar*) _tmp25_;
#line 497 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp26_ = expected_personas1;
#line 497 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp27_ = id;
#line 497 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp26_, _tmp27_);
#line 498 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp28_ = expected_personas1_detailed;
#line 498 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp29_ = id;
#line 498 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp28_, _tmp29_);
#line 499 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp30_ = expected_personas2;
#line 499 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp31_ = id;
#line 499 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp30_, _tmp31_);
#line 500 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp32_ = expected_personas2_detailed;
#line 500 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp33_ = id;
#line 500 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp32_, _tmp33_);
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_free0 (id);
#line 2633 "aggregation.c"
		}
#line 495 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_id_it);
#line 2637 "aggregation.c"
	}
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp34_ = NULL;
		GeeSet* _tmp35_ = NULL;
		GeeSet* _tmp36_ = NULL;
		GeeIterator* _tmp37_ = NULL;
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp34_ = _data3_->individual1;
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp35_ = folks_individual_get_personas (_tmp34_);
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp36_ = _tmp35_;
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp37_ = gee_iterable_iterator ((GeeIterable*) _tmp36_);
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_p_it = _tmp37_;
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2657 "aggregation.c"
			GeeIterator* _tmp38_ = NULL;
			gboolean _tmp39_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp40_ = NULL;
			gpointer _tmp41_ = NULL;
			gboolean _tmp42_ = FALSE;
			gboolean _tmp43_ = FALSE;
			GeeHashSet* _tmp44_ = NULL;
			FolksPersona* _tmp45_ = NULL;
			const gchar* _tmp46_ = NULL;
			const gchar* _tmp47_ = NULL;
			gboolean _tmp48_ = FALSE;
			gboolean _tmp52_ = FALSE;
			gboolean _tmp56_ = FALSE;
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp38_ = _p_it;
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp39_ = gee_iterator_next (_tmp38_);
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp39_) {
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 2680 "aggregation.c"
			}
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp40_ = _p_it;
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp41_ = gee_iterator_get (_tmp40_);
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp41_;
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp44_ = expected_personas1;
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp45_ = p;
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp46_ = folks_persona_get_display_id (_tmp45_);
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp47_ = _tmp46_;
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp48_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp44_, _tmp47_);
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp48_) {
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp43_ = TRUE;
#line 2702 "aggregation.c"
			} else {
				FolksPersona* _tmp49_ = NULL;
				const gchar* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
#line 506 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp49_ = p;
#line 506 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp50_ = folks_persona_get_display_id (_tmp49_);
#line 506 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp51_ = _tmp50_;
#line 506 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp43_ = g_strcmp0 (_tmp51_, "0") == 0;
#line 2715 "aggregation.c"
			}
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp52_ = _tmp43_;
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp52_) {
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp42_ = TRUE;
#line 2723 "aggregation.c"
			} else {
				FolksPersona* _tmp53_ = NULL;
				const gchar* _tmp54_ = NULL;
				const gchar* _tmp55_ = NULL;
#line 506 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp53_ = p;
#line 506 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp54_ = folks_persona_get_display_id (_tmp53_);
#line 506 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp55_ = _tmp54_;
#line 506 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp42_ = g_strcmp0 (_tmp55_, "1") == 0;
#line 2736 "aggregation.c"
			}
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp56_ = _tmp42_;
#line 505 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp56_, "expected_personas1.remove (p.display_id) ||               p.display_id == \"0\" || p.display_id == \"1\"");
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2744 "aggregation.c"
		}
#line 503 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2748 "aggregation.c"
	}
#line 509 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp57_ = expected_personas1;
#line 509 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp58_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp57_);
#line 509 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp59_ = _tmp58_;
#line 509 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp59_ == 0, "expected_personas1.size == 0");
#line 2758 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp60_ = NULL;
		GeeSet* _tmp61_ = NULL;
		GeeSet* _tmp62_ = NULL;
		GeeIterator* _tmp63_ = NULL;
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp60_ = _data3_->individual1_detailed;
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp61_ = folks_individual_get_personas (_tmp60_);
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp62_ = _tmp61_;
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp63_ = gee_iterable_iterator ((GeeIterable*) _tmp62_);
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_p_it = _tmp63_;
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2777 "aggregation.c"
			GeeIterator* _tmp64_ = NULL;
			gboolean _tmp65_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp66_ = NULL;
			gpointer _tmp67_ = NULL;
			gboolean _tmp68_ = FALSE;
			gboolean _tmp69_ = FALSE;
			GeeHashSet* _tmp70_ = NULL;
			FolksPersona* _tmp71_ = NULL;
			const gchar* _tmp72_ = NULL;
			const gchar* _tmp73_ = NULL;
			gboolean _tmp74_ = FALSE;
			gboolean _tmp78_ = FALSE;
			gboolean _tmp82_ = FALSE;
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp64_ = _p_it;
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp65_ = gee_iterator_next (_tmp64_);
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp65_) {
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 2800 "aggregation.c"
			}
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp66_ = _p_it;
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp67_ = gee_iterator_get (_tmp66_);
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp67_;
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp70_ = expected_personas1_detailed;
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp71_ = p;
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp72_ = folks_persona_get_display_id (_tmp71_);
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp73_ = _tmp72_;
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp74_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp70_, _tmp73_);
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp74_) {
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp69_ = TRUE;
#line 2822 "aggregation.c"
			} else {
				FolksPersona* _tmp75_ = NULL;
				const gchar* _tmp76_ = NULL;
				const gchar* _tmp77_ = NULL;
#line 514 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp75_ = p;
#line 514 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp76_ = folks_persona_get_display_id (_tmp75_);
#line 514 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp77_ = _tmp76_;
#line 514 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp69_ = g_strcmp0 (_tmp77_, "0") == 0;
#line 2835 "aggregation.c"
			}
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp78_ = _tmp69_;
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp78_) {
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp68_ = TRUE;
#line 2843 "aggregation.c"
			} else {
				FolksPersona* _tmp79_ = NULL;
				const gchar* _tmp80_ = NULL;
				const gchar* _tmp81_ = NULL;
#line 514 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp79_ = p;
#line 514 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp80_ = folks_persona_get_display_id (_tmp79_);
#line 514 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp81_ = _tmp80_;
#line 514 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp68_ = g_strcmp0 (_tmp81_, "1") == 0;
#line 2856 "aggregation.c"
			}
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp82_ = _tmp68_;
#line 513 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp82_, "expected_personas1_detailed.remove (p.display_id) ||               p.display_id == \"0\" || p.display_id == \"1\"");
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2864 "aggregation.c"
		}
#line 511 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2868 "aggregation.c"
	}
#line 517 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp83_ = expected_personas1_detailed;
#line 517 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp84_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp83_);
#line 517 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp85_ = _tmp84_;
#line 517 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp85_ == 0, "expected_personas1_detailed.size == 0");
#line 2878 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp86_ = NULL;
		GeeSet* _tmp87_ = NULL;
		GeeSet* _tmp88_ = NULL;
		GeeIterator* _tmp89_ = NULL;
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp86_ = _data3_->individual2;
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp87_ = folks_individual_get_personas (_tmp86_);
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp88_ = _tmp87_;
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp89_ = gee_iterable_iterator ((GeeIterable*) _tmp88_);
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_p_it = _tmp89_;
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 2897 "aggregation.c"
			GeeIterator* _tmp90_ = NULL;
			gboolean _tmp91_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp92_ = NULL;
			gpointer _tmp93_ = NULL;
			gboolean _tmp94_ = FALSE;
			gboolean _tmp95_ = FALSE;
			GeeHashSet* _tmp96_ = NULL;
			FolksPersona* _tmp97_ = NULL;
			const gchar* _tmp98_ = NULL;
			const gchar* _tmp99_ = NULL;
			gboolean _tmp100_ = FALSE;
			gboolean _tmp104_ = FALSE;
			gboolean _tmp108_ = FALSE;
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp90_ = _p_it;
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp91_ = gee_iterator_next (_tmp90_);
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp91_) {
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 2920 "aggregation.c"
			}
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp92_ = _p_it;
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp93_ = gee_iterator_get (_tmp92_);
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp93_;
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp96_ = expected_personas2;
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp97_ = p;
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp98_ = folks_persona_get_display_id (_tmp97_);
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp99_ = _tmp98_;
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp100_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp96_, _tmp99_);
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp100_) {
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp95_ = TRUE;
#line 2942 "aggregation.c"
			} else {
				FolksPersona* _tmp101_ = NULL;
				const gchar* _tmp102_ = NULL;
				const gchar* _tmp103_ = NULL;
#line 522 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp101_ = p;
#line 522 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp102_ = folks_persona_get_display_id (_tmp101_);
#line 522 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp103_ = _tmp102_;
#line 522 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp95_ = g_strcmp0 (_tmp103_, "0") == 0;
#line 2955 "aggregation.c"
			}
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp104_ = _tmp95_;
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp104_) {
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp94_ = TRUE;
#line 2963 "aggregation.c"
			} else {
				FolksPersona* _tmp105_ = NULL;
				const gchar* _tmp106_ = NULL;
				const gchar* _tmp107_ = NULL;
#line 522 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp105_ = p;
#line 522 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp106_ = folks_persona_get_display_id (_tmp105_);
#line 522 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp107_ = _tmp106_;
#line 522 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp94_ = g_strcmp0 (_tmp107_, "1") == 0;
#line 2976 "aggregation.c"
			}
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp108_ = _tmp94_;
#line 521 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp108_, "expected_personas2.remove (p.display_id) ||               p.display_id == \"0\" || p.display_id == \"1\"");
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 2984 "aggregation.c"
		}
#line 519 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 2988 "aggregation.c"
	}
#line 525 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp109_ = expected_personas2;
#line 525 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp110_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp109_);
#line 525 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp111_ = _tmp110_;
#line 525 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp111_ == 0, "expected_personas2.size == 0");
#line 2998 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp112_ = NULL;
		GeeSet* _tmp113_ = NULL;
		GeeSet* _tmp114_ = NULL;
		GeeIterator* _tmp115_ = NULL;
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp112_ = _data3_->individual2_detailed;
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp113_ = folks_individual_get_personas (_tmp112_);
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp114_ = _tmp113_;
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp115_ = gee_iterable_iterator ((GeeIterable*) _tmp114_);
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_p_it = _tmp115_;
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3017 "aggregation.c"
			GeeIterator* _tmp116_ = NULL;
			gboolean _tmp117_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp118_ = NULL;
			gpointer _tmp119_ = NULL;
			gboolean _tmp120_ = FALSE;
			gboolean _tmp121_ = FALSE;
			GeeHashSet* _tmp122_ = NULL;
			FolksPersona* _tmp123_ = NULL;
			const gchar* _tmp124_ = NULL;
			const gchar* _tmp125_ = NULL;
			gboolean _tmp126_ = FALSE;
			gboolean _tmp130_ = FALSE;
			gboolean _tmp134_ = FALSE;
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp116_ = _p_it;
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp117_ = gee_iterator_next (_tmp116_);
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp117_) {
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 3040 "aggregation.c"
			}
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp118_ = _p_it;
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp119_ = gee_iterator_get (_tmp118_);
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp119_;
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp122_ = expected_personas2_detailed;
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp123_ = p;
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp124_ = folks_persona_get_display_id (_tmp123_);
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp125_ = _tmp124_;
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp126_ = gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp122_, _tmp125_);
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp126_) {
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp121_ = TRUE;
#line 3062 "aggregation.c"
			} else {
				FolksPersona* _tmp127_ = NULL;
				const gchar* _tmp128_ = NULL;
				const gchar* _tmp129_ = NULL;
#line 530 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp127_ = p;
#line 530 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp128_ = folks_persona_get_display_id (_tmp127_);
#line 530 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp129_ = _tmp128_;
#line 530 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp121_ = g_strcmp0 (_tmp129_, "0") == 0;
#line 3075 "aggregation.c"
			}
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp130_ = _tmp121_;
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp130_) {
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp120_ = TRUE;
#line 3083 "aggregation.c"
			} else {
				FolksPersona* _tmp131_ = NULL;
				const gchar* _tmp132_ = NULL;
				const gchar* _tmp133_ = NULL;
#line 530 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp131_ = p;
#line 530 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp132_ = folks_persona_get_display_id (_tmp131_);
#line 530 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp133_ = _tmp132_;
#line 530 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp120_ = g_strcmp0 (_tmp133_, "1") == 0;
#line 3096 "aggregation.c"
			}
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp134_ = _tmp120_;
#line 529 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp134_, "expected_personas2_detailed.remove (p.display_id) ||               p.display_id == \"0\" || p.display_id == \"1\"");
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 3104 "aggregation.c"
		}
#line 527 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 3108 "aggregation.c"
	}
#line 533 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp135_ = expected_personas2_detailed;
#line 533 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp136_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp135_);
#line 533 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp137_ = _tmp136_;
#line 533 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp137_ == 0, "expected_personas2_detailed.size == 0");
#line 536 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp138_ = tp_backend;
#line 536 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp139_ = account2_handle;
#line 536 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp138_, _tmp139_);
#line 537 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp140_ = tp_backend;
#line 537 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp141_ = account1_handle;
#line 537 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp140_, _tmp141_);
#line 538 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data3_->aggregator);
#line 538 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data3_->aggregator = NULL;
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas2_detailed);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas2);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas1_detailed);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (expected_personas1);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (tp_backend);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block3_data_unref (_data3_);
#line 412 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data3_ = NULL;
#line 3150 "aggregation.c"
}


static void _aggregation_tests_test_linkable_properties_individuals_changed (AggregationTests* self, gboolean detailed, guint num_personas, GeeCollection* added, GeeSet* removed, FolksIndividual** individual1, FolksIndividual** individual2) {
#line 541 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 541 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 541 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 3161 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3174 "aggregation.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_ = NULL;
			gboolean _tmp9_ = FALSE;
			FolksIndividual* _tmp10_ = NULL;
			gboolean _tmp11_ = FALSE;
			FolksIndividual* _tmp12_ = NULL;
			gboolean _tmp13_ = FALSE;
			gboolean _tmp14_ = FALSE;
			gboolean _tmp21_ = FALSE;
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 3197 "aggregation.c"
			}
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 548 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 548 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 548 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 3211 "aggregation.c"
			} else {
				gboolean _tmp8_ = FALSE;
#line 548 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 548 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 3218 "aggregation.c"
			}
#line 548 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp9_ = _tmp6_;
#line 548 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp9_, "i != null || detailed == true");
#line 549 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 549 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp10_ == NULL) {
#line 551 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 551 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				continue;
#line 3232 "aggregation.c"
			}
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp12_ = i;
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp13_ = folks_individual_get_is_user (_tmp12_);
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp14_ = _tmp13_;
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp14_) {
#line 3242 "aggregation.c"
				FolksIndividual* _tmp15_ = NULL;
				GeeSet* _tmp16_ = NULL;
				GeeSet* _tmp17_ = NULL;
				gint _tmp18_ = 0;
				gint _tmp19_ = 0;
				guint _tmp20_ = 0U;
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp15_ = i;
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp16_ = folks_individual_get_personas (_tmp15_);
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp17_ = _tmp16_;
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp19_ = _tmp18_;
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp20_ = num_personas;
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp11_ = ((guint) _tmp19_) == _tmp20_;
#line 3263 "aggregation.c"
			} else {
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp11_ = FALSE;
#line 3267 "aggregation.c"
			}
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp21_ = _tmp11_;
#line 554 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp21_) {
#line 3273 "aggregation.c"
				FolksIndividual* _tmp22_ = NULL;
				FolksIndividual* _tmp23_ = NULL;
#line 556 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp22_ = i;
#line 556 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp23_ = *individual1;
#line 556 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				if (_tmp22_ == _tmp23_) {
#line 558 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					*individual1 = NULL;
#line 3284 "aggregation.c"
				} else {
					FolksIndividual* _tmp24_ = NULL;
					FolksIndividual* _tmp25_ = NULL;
#line 560 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp24_ = i;
#line 560 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp25_ = *individual2;
#line 560 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					if (_tmp24_ == _tmp25_) {
#line 562 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						*individual2 = NULL;
#line 3296 "aggregation.c"
					} else {
						guint _tmp26_ = 0U;
						FolksIndividual* _tmp27_ = NULL;
						const gchar* _tmp28_ = NULL;
						const gchar* _tmp29_ = NULL;
#line 566 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp26_ = num_personas;
#line 566 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp27_ = i;
#line 566 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp28_ = folks_individual_get_id (_tmp27_);
#line 566 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp29_ = _tmp28_;
#line 566 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						g_critical ("aggregation.vala:566: Unknown %u-persona individual: %s", _tmp26_, _tmp29_);
#line 568 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						g_assert_not_reached ();
#line 3314 "aggregation.c"
					}
				}
			}
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 3320 "aggregation.c"
		}
#line 546 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 3324 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp30_ = NULL;
		GeeIterator* _tmp31_ = NULL;
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp30_ = added;
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp31_ = gee_iterable_iterator ((GeeIterable*) _tmp30_);
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp31_;
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3338 "aggregation.c"
			GeeIterator* _tmp32_ = NULL;
			gboolean _tmp33_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp34_ = NULL;
			gpointer _tmp35_ = NULL;
			gboolean _tmp36_ = FALSE;
			FolksIndividual* _tmp37_ = NULL;
			gboolean _tmp39_ = FALSE;
			FolksIndividual* _tmp40_ = NULL;
			gboolean _tmp41_ = FALSE;
			FolksIndividual* _tmp42_ = NULL;
			gboolean _tmp43_ = FALSE;
			gboolean _tmp44_ = FALSE;
			gboolean _tmp51_ = FALSE;
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp32_ = _i_it;
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp33_ = gee_iterator_next (_tmp32_);
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp33_) {
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 3361 "aggregation.c"
			}
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp34_ = _i_it;
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp35_ = gee_iterator_get (_tmp34_);
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp35_;
#line 575 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp37_ = i;
#line 575 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp37_ != NULL) {
#line 575 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp36_ = TRUE;
#line 3375 "aggregation.c"
			} else {
				gboolean _tmp38_ = FALSE;
#line 575 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp38_ = detailed;
#line 575 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp36_ = _tmp38_ == TRUE;
#line 3382 "aggregation.c"
			}
#line 575 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp39_ = _tmp36_;
#line 575 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp39_, "i != null || detailed == true");
#line 576 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp40_ = i;
#line 576 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp40_ == NULL) {
#line 578 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 578 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				continue;
#line 3396 "aggregation.c"
			}
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp42_ = i;
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp43_ = folks_individual_get_is_user (_tmp42_);
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp44_ = _tmp43_;
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp44_) {
#line 3406 "aggregation.c"
				FolksIndividual* _tmp45_ = NULL;
				GeeSet* _tmp46_ = NULL;
				GeeSet* _tmp47_ = NULL;
				gint _tmp48_ = 0;
				gint _tmp49_ = 0;
				guint _tmp50_ = 0U;
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp45_ = i;
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp46_ = folks_individual_get_personas (_tmp45_);
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp47_ = _tmp46_;
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp48_ = gee_collection_get_size ((GeeCollection*) _tmp47_);
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp49_ = _tmp48_;
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp50_ = num_personas;
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp41_ = ((guint) _tmp49_) == _tmp50_;
#line 3427 "aggregation.c"
			} else {
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp41_ = FALSE;
#line 3431 "aggregation.c"
			}
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp51_ = _tmp41_;
#line 581 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp51_) {
#line 3437 "aggregation.c"
				gboolean _tmp52_ = FALSE;
				FolksIndividual* _tmp53_ = NULL;
				gboolean _tmp56_ = FALSE;
#line 583 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp53_ = *individual1;
#line 583 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				if (_tmp53_ == NULL) {
#line 3445 "aggregation.c"
					FolksIndividual* _tmp54_ = NULL;
					FolksIndividual* _tmp55_ = NULL;
#line 583 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp54_ = *individual2;
#line 583 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp55_ = i;
#line 583 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp52_ = _tmp54_ != _tmp55_;
#line 3454 "aggregation.c"
				} else {
#line 583 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp52_ = FALSE;
#line 3458 "aggregation.c"
				}
#line 583 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp56_ = _tmp52_;
#line 583 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				if (_tmp56_) {
#line 3464 "aggregation.c"
					FolksIndividual* _tmp57_ = NULL;
#line 585 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp57_ = i;
#line 585 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					*individual1 = _tmp57_;
#line 3470 "aggregation.c"
				} else {
					gboolean _tmp58_ = FALSE;
					FolksIndividual* _tmp59_ = NULL;
					gboolean _tmp62_ = FALSE;
#line 587 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp59_ = *individual2;
#line 587 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					if (_tmp59_ == NULL) {
#line 3479 "aggregation.c"
						FolksIndividual* _tmp60_ = NULL;
						FolksIndividual* _tmp61_ = NULL;
#line 587 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp60_ = *individual1;
#line 587 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp61_ = i;
#line 587 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp58_ = _tmp60_ != _tmp61_;
#line 3488 "aggregation.c"
					} else {
#line 587 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp58_ = FALSE;
#line 3492 "aggregation.c"
					}
#line 587 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp62_ = _tmp58_;
#line 587 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					if (_tmp62_) {
#line 3498 "aggregation.c"
						FolksIndividual* _tmp63_ = NULL;
#line 589 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp63_ = i;
#line 589 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						*individual2 = _tmp63_;
#line 3504 "aggregation.c"
					} else {
						gboolean _tmp64_ = FALSE;
						FolksIndividual* _tmp65_ = NULL;
						FolksIndividual* _tmp66_ = NULL;
						gboolean _tmp69_ = FALSE;
#line 591 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp65_ = *individual1;
#line 591 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp66_ = i;
#line 591 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						if (_tmp65_ != _tmp66_) {
#line 3516 "aggregation.c"
							FolksIndividual* _tmp67_ = NULL;
							FolksIndividual* _tmp68_ = NULL;
#line 591 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp67_ = *individual2;
#line 591 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp68_ = i;
#line 591 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp64_ = _tmp67_ != _tmp68_;
#line 3525 "aggregation.c"
						} else {
#line 591 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp64_ = FALSE;
#line 3529 "aggregation.c"
						}
#line 591 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp69_ = _tmp64_;
#line 591 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						if (_tmp69_) {
#line 3535 "aggregation.c"
							guint _tmp70_ = 0U;
							FolksIndividual* _tmp71_ = NULL;
							const gchar* _tmp72_ = NULL;
							const gchar* _tmp73_ = NULL;
#line 593 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp70_ = num_personas;
#line 593 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp71_ = i;
#line 593 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp72_ = folks_individual_get_id (_tmp71_);
#line 593 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							_tmp73_ = _tmp72_;
#line 593 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							g_critical ("aggregation.vala:593: Unknown %u-persona individual: %s", _tmp70_, _tmp73_);
#line 595 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							g_assert_not_reached ();
#line 3552 "aggregation.c"
						}
					}
				}
			}
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 3559 "aggregation.c"
		}
#line 573 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 3563 "aggregation.c"
	}
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return _data4_;
#line 3573 "aggregation.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 3582 "aggregation.c"
		AggregationTests * self;
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		self = _data4_->self;
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data4_->aggregator);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data4_->user_individual_detailed);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data4_->user_individual);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_slice_free (Block4Data, _data4_);
#line 3596 "aggregation.c"
	}
}


static void __lambda14_ (Block4Data* _data4_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
#line 621 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 621 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 623 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 623 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 623 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 624 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 624 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 624 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 626 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_user_individuals_changed (self, TRUE, added, removed, &_data4_->user_individual_detailed);
#line 621 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 621 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 3631 "aggregation.c"
}


static void ___lambda14__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 620 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda14_ (self, changes);
#line 3638 "aggregation.c"
}


static void __lambda15_ (Block4Data* _data4_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests * self;
	GeeSet* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 630 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 630 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 630 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 632 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 632 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 632 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_user_individuals_changed (self, FALSE, (GeeCollection*) _tmp0_, _tmp1_, &_data4_->user_individual);
#line 3658 "aggregation.c"
}


static void ___lambda15__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 629 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda15_ (self, added, removed, message, actor, reason);
#line 3665 "aggregation.c"
}


static void __lambda17_ (Block4Data* _data4_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 642 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 642 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 3676 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 646 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data4_->aggregator;
#line 646 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 646 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 646 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 3688 "aggregation.c"
			goto __catch3_g_error;
		}
	}
	goto __finally3;
	__catch3_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 644 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 644 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 650 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 650 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:650: Failed to prepare aggregator: %s", _tmp2_);
#line 652 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 644 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 3709 "aggregation.c"
	}
	__finally3:
#line 644 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 644 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 644 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 644 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 3720 "aggregation.c"
	}
}


static void ___lambda17__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 642 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda17_ (self, source_object, res);
#line 642 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block4_data_unref (self);
#line 3730 "aggregation.c"
}


static gboolean __lambda16_ (Block4Data* _data4_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 640 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data4_->self;
#line 642 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data4_->aggregator;
#line 642 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda17__gasync_ready_callback, block4_data_ref (_data4_));
#line 656 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 656 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 3748 "aggregation.c"
}


static gboolean ___lambda16__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda16_ (self);
#line 640 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 3757 "aggregation.c"
}


void aggregation_tests_test_user (AggregationTests* self) {
	Block4Data* _data4_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* tp_backend = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	TpTestsBackend* _tmp3_ = NULL;
	void* account1_handle = NULL;
	TpTestsBackend* _tmp4_ = NULL;
	void* _tmp5_ = NULL;
	void* account2_handle = NULL;
	TpTestsBackend* _tmp6_ = NULL;
	void* _tmp7_ = NULL;
	FolksIndividualAggregator* _tmp8_ = NULL;
	gulong individuals_changed_detailed_id = 0UL;
	FolksIndividualAggregator* _tmp9_ = NULL;
	gulong _tmp10_ = 0UL;
	gulong individuals_changed_id = 0UL;
	FolksIndividualAggregator* _tmp11_ = NULL;
	gulong _tmp12_ = 0UL;
	GMainLoop* _tmp13_ = NULL;
	FolksIndividualAggregator* _tmp14_ = NULL;
	FolksIndividual* _tmp15_ = NULL;
	FolksIndividual* _tmp16_ = NULL;
	FolksIndividual* _tmp17_ = NULL;
	FolksIndividualAggregator* _tmp18_ = NULL;
	FolksIndividual* _tmp19_ = NULL;
	FolksIndividual* _tmp20_ = NULL;
	FolksIndividual* _tmp21_ = NULL;
	FolksIndividual* _tmp22_ = NULL;
	GeeSet* _tmp23_ = NULL;
	GeeSet* _tmp24_ = NULL;
	gint _tmp25_ = 0;
	gint _tmp26_ = 0;
	FolksIndividual* _tmp27_ = NULL;
	GeeSet* _tmp28_ = NULL;
	GeeSet* _tmp29_ = NULL;
	gint _tmp30_ = 0;
	gint _tmp31_ = 0;
	GeeHashSet* display_ids = NULL;
	GeeHashSet* _tmp32_ = NULL;
	gboolean _tmp45_ = FALSE;
	GeeHashSet* _tmp46_ = NULL;
	gboolean _tmp47_ = FALSE;
	gboolean _tmp50_ = FALSE;
	GeeHashSet* display_ids_detailed = NULL;
	GeeHashSet* _tmp51_ = NULL;
	gboolean _tmp64_ = FALSE;
	GeeHashSet* _tmp65_ = NULL;
	gboolean _tmp66_ = FALSE;
	gboolean _tmp69_ = FALSE;
	FolksIndividualAggregator* _tmp70_ = NULL;
	gulong _tmp71_ = 0UL;
	FolksIndividualAggregator* _tmp72_ = NULL;
	gulong _tmp73_ = 0UL;
	TpTestsBackend* _tmp74_ = NULL;
	void* _tmp75_ = NULL;
	TpTestsBackend* _tmp76_ = NULL;
	void* _tmp77_ = NULL;
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data4_ = g_slice_new0 (Block4Data);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data4_->_ref_count_ = 1;
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data4_->self = g_object_ref (self);
#line 605 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 605 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 607 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 607 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "");
#line 609 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 609 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend));
#line 609 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_backend = _tmp3_;
#line 610 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp4_ = tp_backend;
#line 610 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_tests_backend_add_account (_tmp4_, "protocol", "me@example.com", "cm", "account");
#line 610 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp5_;
#line 612 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp6_ = tp_backend;
#line 612 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp7_ = tp_tests_backend_add_account (_tmp6_, "protocol", "me2@example.com", "cm", "account2");
#line 612 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp7_;
#line 615 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data4_->user_individual = NULL;
#line 616 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data4_->user_individual_detailed = NULL;
#line 619 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp8_ = folks_individual_aggregator_dup ();
#line 619 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data4_->aggregator = _tmp8_;
#line 620 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data4_->aggregator;
#line 620 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp10_ = g_signal_connect_data (_tmp9_, "individuals-changed-detailed", (GCallback) ___lambda14__folks_individual_aggregator_individuals_changed_detailed, block4_data_ref (_data4_), (GClosureNotify) block4_data_unref, 0);
#line 620 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	individuals_changed_detailed_id = _tmp10_;
#line 629 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp11_ = _data4_->aggregator;
#line 629 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp12_ = g_signal_connect_data (_tmp11_, "individuals-changed", (GCallback) ___lambda15__folks_individual_aggregator_individuals_changed, block4_data_ref (_data4_), (GClosureNotify) block4_data_unref, 0);
#line 629 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	individuals_changed_id = _tmp12_;
#line 640 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda16__gsource_func, block4_data_ref (_data4_), block4_data_unref);
#line 659 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp13_ = main_loop;
#line 659 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp13_, 3);
#line 663 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp14_ = _data4_->aggregator;
#line 663 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp15_ = folks_individual_aggregator_get_user (_tmp14_);
#line 663 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp16_ = _tmp15_;
#line 663 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp17_ = _data4_->user_individual;
#line 663 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp16_ == _tmp17_, "aggregator.user == user_individual");
#line 664 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp18_ = _data4_->aggregator;
#line 664 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp19_ = folks_individual_aggregator_get_user (_tmp18_);
#line 664 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp20_ = _tmp19_;
#line 664 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp21_ = _data4_->user_individual_detailed;
#line 664 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp20_ == _tmp21_, "aggregator.user == user_individual_detailed");
#line 667 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp22_ = _data4_->user_individual;
#line 667 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp23_ = folks_individual_get_personas (_tmp22_);
#line 667 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp24_ = _tmp23_;
#line 667 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp25_ = gee_collection_get_size ((GeeCollection*) _tmp24_);
#line 667 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp26_ = _tmp25_;
#line 667 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp26_ == 2, "user_individual.personas.size == 2");
#line 668 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp27_ = _data4_->user_individual_detailed;
#line 668 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp28_ = folks_individual_get_personas (_tmp27_);
#line 668 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp29_ = _tmp28_;
#line 668 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp30_ = gee_collection_get_size ((GeeCollection*) _tmp29_);
#line 668 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp31_ = _tmp30_;
#line 668 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp31_ == 2, "user_individual_detailed.personas.size == 2");
#line 670 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp32_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 670 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	display_ids = _tmp32_;
#line 3929 "aggregation.c"
	{
		GeeIterator* _persona_it = NULL;
		FolksIndividual* _tmp33_ = NULL;
		GeeSet* _tmp34_ = NULL;
		GeeSet* _tmp35_ = NULL;
		GeeIterator* _tmp36_ = NULL;
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp33_ = _data4_->user_individual;
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp34_ = folks_individual_get_personas (_tmp33_);
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp35_ = _tmp34_;
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp36_ = gee_iterable_iterator ((GeeIterable*) _tmp35_);
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_persona_it = _tmp36_;
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 3948 "aggregation.c"
			GeeIterator* _tmp37_ = NULL;
			gboolean _tmp38_ = FALSE;
			FolksPersona* persona = NULL;
			GeeIterator* _tmp39_ = NULL;
			gpointer _tmp40_ = NULL;
			GeeHashSet* _tmp41_ = NULL;
			FolksPersona* _tmp42_ = NULL;
			const gchar* _tmp43_ = NULL;
			const gchar* _tmp44_ = NULL;
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp37_ = _persona_it;
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp38_ = gee_iterator_next (_tmp37_);
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp38_) {
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 3966 "aggregation.c"
			}
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp39_ = _persona_it;
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp40_ = gee_iterator_get (_tmp39_);
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			persona = (FolksPersona*) _tmp40_;
#line 673 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp41_ = display_ids;
#line 673 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp42_ = persona;
#line 673 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp43_ = folks_persona_get_display_id (_tmp42_);
#line 673 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp44_ = _tmp43_;
#line 673 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp41_, _tmp44_);
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 3986 "aggregation.c"
		}
#line 671 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_persona_it);
#line 3990 "aggregation.c"
	}
#line 676 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp46_ = display_ids;
#line 676 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp47_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp46_, "me@example.com");
#line 676 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_tmp47_) {
#line 3998 "aggregation.c"
		GeeHashSet* _tmp48_ = NULL;
		gboolean _tmp49_ = FALSE;
#line 677 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp48_ = display_ids;
#line 677 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp49_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp48_, "me2@example.com");
#line 677 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp45_ = _tmp49_;
#line 4007 "aggregation.c"
	} else {
#line 676 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp45_ = FALSE;
#line 4011 "aggregation.c"
	}
#line 676 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp50_ = _tmp45_;
#line 676 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp50_, "display_ids.contains (\"me@example.com\") &&           display_ids.contains (\"me2@example.com\")");
#line 679 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp51_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 679 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	display_ids_detailed = _tmp51_;
#line 4021 "aggregation.c"
	{
		GeeIterator* _persona_it = NULL;
		FolksIndividual* _tmp52_ = NULL;
		GeeSet* _tmp53_ = NULL;
		GeeSet* _tmp54_ = NULL;
		GeeIterator* _tmp55_ = NULL;
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp52_ = _data4_->user_individual_detailed;
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp53_ = folks_individual_get_personas (_tmp52_);
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp54_ = _tmp53_;
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp55_ = gee_iterable_iterator ((GeeIterable*) _tmp54_);
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_persona_it = _tmp55_;
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4040 "aggregation.c"
			GeeIterator* _tmp56_ = NULL;
			gboolean _tmp57_ = FALSE;
			FolksPersona* persona = NULL;
			GeeIterator* _tmp58_ = NULL;
			gpointer _tmp59_ = NULL;
			GeeHashSet* _tmp60_ = NULL;
			FolksPersona* _tmp61_ = NULL;
			const gchar* _tmp62_ = NULL;
			const gchar* _tmp63_ = NULL;
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp56_ = _persona_it;
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp57_ = gee_iterator_next (_tmp56_);
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp57_) {
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 4058 "aggregation.c"
			}
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp58_ = _persona_it;
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp59_ = gee_iterator_get (_tmp58_);
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			persona = (FolksPersona*) _tmp59_;
#line 682 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp60_ = display_ids_detailed;
#line 682 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp61_ = persona;
#line 682 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp62_ = folks_persona_get_display_id (_tmp61_);
#line 682 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp63_ = _tmp62_;
#line 682 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp60_, _tmp63_);
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 4078 "aggregation.c"
		}
#line 680 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_persona_it);
#line 4082 "aggregation.c"
	}
#line 685 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp65_ = display_ids_detailed;
#line 685 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp66_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp65_, "me@example.com");
#line 685 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_tmp66_) {
#line 4090 "aggregation.c"
		GeeHashSet* _tmp67_ = NULL;
		gboolean _tmp68_ = FALSE;
#line 686 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp67_ = display_ids_detailed;
#line 686 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp68_ = gee_abstract_collection_contains ((GeeAbstractCollection*) _tmp67_, "me2@example.com");
#line 686 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp64_ = _tmp68_;
#line 4099 "aggregation.c"
	} else {
#line 685 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp64_ = FALSE;
#line 4103 "aggregation.c"
	}
#line 685 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp69_ = _tmp64_;
#line 685 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp69_, "display_ids_detailed.contains (\"me@example.com\") &&           display_ids_detailed.contains (\"me2@example.com\")");
#line 688 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp70_ = _data4_->aggregator;
#line 688 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp71_ = individuals_changed_id;
#line 688 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp70_, _tmp71_);
#line 689 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp72_ = _data4_->aggregator;
#line 689 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp73_ = individuals_changed_detailed_id;
#line 689 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp72_, _tmp73_);
#line 692 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp74_ = tp_backend;
#line 692 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp75_ = account2_handle;
#line 692 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp74_, _tmp75_);
#line 693 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp76_ = tp_backend;
#line 693 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp77_ = account1_handle;
#line 693 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (_tmp76_, _tmp77_);
#line 694 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data4_->aggregator);
#line 694 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data4_->aggregator = NULL;
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (display_ids_detailed);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (display_ids);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (tp_backend);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block4_data_unref (_data4_);
#line 603 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data4_ = NULL;
#line 4149 "aggregation.c"
}


static void _aggregation_tests_test_user_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed, FolksIndividual** user_individual) {
#line 697 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 697 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 697 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 4160 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4173 "aggregation.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_ = NULL;
			gboolean _tmp9_ = FALSE;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
			gboolean _tmp13_ = FALSE;
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 4194 "aggregation.c"
			}
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 704 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 704 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 704 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 4208 "aggregation.c"
			} else {
				gboolean _tmp8_ = FALSE;
#line 704 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 704 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 4215 "aggregation.c"
			}
#line 704 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp9_ = _tmp6_;
#line 704 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp9_, "i != null || detailed == true");
#line 705 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 705 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp10_ == NULL) {
#line 707 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 707 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				continue;
#line 4229 "aggregation.c"
			}
#line 710 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp11_ = i;
#line 710 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp12_ = folks_individual_get_is_user (_tmp11_);
#line 710 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp13_ = _tmp12_;
#line 710 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp13_) {
#line 4239 "aggregation.c"
				FolksIndividual* _tmp14_ = NULL;
				FolksIndividual* _tmp15_ = NULL;
#line 712 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp14_ = *user_individual;
#line 712 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp15_ = i;
#line 712 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_vala_assert (_tmp14_ == _tmp15_, "user_individual == i");
#line 713 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (*user_individual);
#line 713 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				*user_individual = NULL;
#line 4252 "aggregation.c"
			}
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4256 "aggregation.c"
		}
#line 702 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4260 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp16_ = NULL;
		GeeIterator* _tmp17_ = NULL;
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp16_ = added;
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp17_;
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4274 "aggregation.c"
			GeeIterator* _tmp18_ = NULL;
			gboolean _tmp19_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp20_ = NULL;
			gpointer _tmp21_ = NULL;
			gboolean _tmp22_ = FALSE;
			FolksIndividual* _tmp23_ = NULL;
			gboolean _tmp25_ = FALSE;
			FolksIndividual* _tmp26_ = NULL;
			FolksIndividual* _tmp27_ = NULL;
			gboolean _tmp28_ = FALSE;
			gboolean _tmp29_ = FALSE;
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp18_ = _i_it;
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp19_ = gee_iterator_next (_tmp18_);
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp19_) {
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 4295 "aggregation.c"
			}
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp20_ = _i_it;
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp21_ = gee_iterator_get (_tmp20_);
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp21_;
#line 719 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp23_ = i;
#line 719 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp23_ != NULL) {
#line 719 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp22_ = TRUE;
#line 4309 "aggregation.c"
			} else {
				gboolean _tmp24_ = FALSE;
#line 719 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp24_ = detailed;
#line 719 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp22_ = _tmp24_ == TRUE;
#line 4316 "aggregation.c"
			}
#line 719 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp25_ = _tmp22_;
#line 719 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp25_, "i != null || detailed == true");
#line 720 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp26_ = i;
#line 720 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp26_ == NULL) {
#line 722 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 722 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				continue;
#line 4330 "aggregation.c"
			}
#line 725 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp27_ = i;
#line 725 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp28_ = folks_individual_get_is_user (_tmp27_);
#line 725 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp29_ = _tmp28_;
#line 725 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp29_) {
#line 4340 "aggregation.c"
				FolksIndividual* _tmp30_ = NULL;
				FolksIndividual* _tmp31_ = NULL;
				FolksIndividual* _tmp32_ = NULL;
#line 727 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp30_ = *user_individual;
#line 727 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_vala_assert (_tmp30_ == NULL, "user_individual == null");
#line 728 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp31_ = i;
#line 728 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp32_ = _g_object_ref0 (_tmp31_);
#line 728 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (*user_individual);
#line 728 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				*user_individual = _tmp32_;
#line 4356 "aggregation.c"
			}
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4360 "aggregation.c"
		}
#line 717 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4364 "aggregation.c"
	}
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return _data5_;
#line 4374 "aggregation.c"
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 4383 "aggregation.c"
		AggregationTests * self;
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		self = _data5_->self;
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data5_->aggregator);
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_slice_free (Block5Data, _data5_);
#line 4393 "aggregation.c"
	}
}


static void __lambda18_ (AggregationTests* self, GeeMultiMap* changes) {
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
#line 751 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 753 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 753 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_keys (_tmp0_);
#line 753 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	removed = _tmp1_;
#line 754 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 754 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_values (_tmp2_);
#line 754 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	added = _tmp3_;
#line 756 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_untrusted_store_individuals_changed (self, TRUE, added, removed);
#line 751 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 751 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 4425 "aggregation.c"
}


static void ___lambda18__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 750 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda18_ (self, changes);
#line 4432 "aggregation.c"
}


static void __lambda19_ (AggregationTests* self, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	GeeSet* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
#line 759 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 759 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 761 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = added;
#line 761 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = removed;
#line 761 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_aggregation_tests_test_untrusted_store_individuals_changed (self, FALSE, (GeeCollection*) _tmp0_, _tmp1_);
#line 4449 "aggregation.c"
}


static void ___lambda19__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 758 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda19_ (self, added, removed, message, actor, reason);
#line 4456 "aggregation.c"
}


static void __lambda21_ (Block5Data* _data5_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 771 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data5_->self;
#line 771 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 4467 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 775 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data5_->aggregator;
#line 775 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 775 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 775 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 4479 "aggregation.c"
			goto __catch4_g_error;
		}
	}
	goto __finally4;
	__catch4_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 773 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 773 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 779 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 779 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:779: Failed to prepare aggregator: %s", _tmp2_);
#line 781 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 773 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 4500 "aggregation.c"
	}
	__finally4:
#line 773 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 773 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 773 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 773 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 4511 "aggregation.c"
	}
}


static void ___lambda21__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 771 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda21_ (self, source_object, res);
#line 771 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block5_data_unref (self);
#line 4521 "aggregation.c"
}


static gboolean __lambda20_ (Block5Data* _data5_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 769 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data5_->self;
#line 771 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data5_->aggregator;
#line 771 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda21__gasync_ready_callback, block5_data_ref (_data5_));
#line 785 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 785 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 4539 "aggregation.c"
}


static gboolean ___lambda20__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda20_ (self);
#line 769 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 4548 "aggregation.c"
}


void aggregation_tests_test_untrusted_store (AggregationTests* self) {
	Block5Data* _data5_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* tp_backend = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	TpTestsBackend* _tmp3_ = NULL;
	void* account1_handle = NULL;
	void* _tmp4_ = NULL;
	void* account2_handle = NULL;
	void* _tmp5_ = NULL;
	FolksIndividualAggregator* _tmp6_ = NULL;
	gulong individuals_changed_detailed_id = 0UL;
	FolksIndividualAggregator* _tmp7_ = NULL;
	gulong _tmp8_ = 0UL;
	gulong individuals_changed_id = 0UL;
	FolksIndividualAggregator* _tmp9_ = NULL;
	gulong _tmp10_ = 0UL;
	FolksIndividualAggregator* _tmp11_ = NULL;
	FolksIndividualAggregator* _tmp12_ = NULL;
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data5_ = g_slice_new0 (Block5Data);
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data5_->_ref_count_ = 1;
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data5_->self = g_object_ref (self);
#line 738 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 738 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 740 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 740 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "");
#line 742 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 742 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend));
#line 742 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_backend = _tmp3_;
#line 743 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp4_ = tp_tests_backend_add_account (tp_backend, "irc", "me@example.com", "cm", "account");
#line 743 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	account1_handle = _tmp4_;
#line 745 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp5_ = tp_tests_backend_add_account (tp_backend, "irc", "me2@example.com", "cm", "account2");
#line 745 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	account2_handle = _tmp5_;
#line 749 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp6_ = folks_individual_aggregator_dup ();
#line 749 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data5_->aggregator = _tmp6_;
#line 750 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp7_ = _data5_->aggregator;
#line 750 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp8_ = g_signal_connect_object (_tmp7_, "individuals-changed-detailed", (GCallback) ___lambda18__folks_individual_aggregator_individuals_changed_detailed, self, 0);
#line 750 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	individuals_changed_detailed_id = _tmp8_;
#line 758 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data5_->aggregator;
#line 758 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp10_ = g_signal_connect_object (_tmp9_, "individuals-changed", (GCallback) ___lambda19__folks_individual_aggregator_individuals_changed, self, 0);
#line 758 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	individuals_changed_id = _tmp10_;
#line 769 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda20__gsource_func, block5_data_ref (_data5_), block5_data_unref);
#line 788 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 790 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp11_ = _data5_->aggregator;
#line 790 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp11_, individuals_changed_id);
#line 791 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp12_ = _data5_->aggregator;
#line 791 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp12_, individuals_changed_detailed_id);
#line 794 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (tp_backend, account2_handle);
#line 795 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (tp_backend, account1_handle);
#line 796 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data5_->aggregator);
#line 796 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data5_->aggregator = NULL;
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (tp_backend);
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block5_data_unref (_data5_);
#line 736 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data5_ = NULL;
#line 4647 "aggregation.c"
}


static void _aggregation_tests_test_untrusted_store_individuals_changed (AggregationTests* self, gboolean detailed, GeeCollection* added, GeeSet* removed) {
#line 799 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 799 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 799 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 4658 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4671 "aggregation.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gboolean _tmp6_ = FALSE;
			FolksIndividual* _tmp7_ = NULL;
			gboolean _tmp9_ = FALSE;
			FolksIndividual* _tmp10_ = NULL;
			gboolean _tmp11_ = FALSE;
			FolksIndividual* _tmp12_ = NULL;
			gboolean _tmp13_ = FALSE;
			gboolean _tmp14_ = FALSE;
			gboolean _tmp20_ = FALSE;
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 4694 "aggregation.c"
			}
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 806 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp7_ = i;
#line 806 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp7_ != NULL) {
#line 806 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp6_ = TRUE;
#line 4708 "aggregation.c"
			} else {
				gboolean _tmp8_ = FALSE;
#line 806 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp8_ = detailed;
#line 806 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp6_ = _tmp8_ == TRUE;
#line 4715 "aggregation.c"
			}
#line 806 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp9_ = _tmp6_;
#line 806 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp9_, "i != null || detailed == true");
#line 807 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 807 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp10_ == NULL) {
#line 809 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 809 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				continue;
#line 4729 "aggregation.c"
			}
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp12_ = i;
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp13_ = folks_individual_get_is_user (_tmp12_);
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp14_ = _tmp13_;
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp14_) {
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp11_ = TRUE;
#line 4741 "aggregation.c"
			} else {
				FolksIndividual* _tmp15_ = NULL;
				GeeSet* _tmp16_ = NULL;
				GeeSet* _tmp17_ = NULL;
				gint _tmp18_ = 0;
				gint _tmp19_ = 0;
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp15_ = i;
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp16_ = folks_individual_get_personas (_tmp15_);
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp17_ = _tmp16_;
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp19_ = _tmp18_;
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp11_ = _tmp19_ == 1;
#line 4760 "aggregation.c"
			}
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp20_ = _tmp11_;
#line 812 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp20_, "i.is_user || i.personas.size == 1");
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4768 "aggregation.c"
		}
#line 804 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4772 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp21_ = NULL;
		GeeIterator* _tmp22_ = NULL;
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp21_ = added;
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp22_;
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 4786 "aggregation.c"
			GeeIterator* _tmp23_ = NULL;
			gboolean _tmp24_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp25_ = NULL;
			gpointer _tmp26_ = NULL;
			gboolean _tmp27_ = FALSE;
			FolksIndividual* _tmp28_ = NULL;
			gboolean _tmp30_ = FALSE;
			FolksIndividual* _tmp31_ = NULL;
			gboolean _tmp32_ = FALSE;
			FolksIndividual* _tmp33_ = NULL;
			gboolean _tmp34_ = FALSE;
			gboolean _tmp35_ = FALSE;
			gboolean _tmp41_ = FALSE;
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp23_ = _i_it;
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp24_ = gee_iterator_next (_tmp23_);
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp24_) {
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 4809 "aggregation.c"
			}
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp25_ = _i_it;
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp26_ = gee_iterator_get (_tmp25_);
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp26_;
#line 817 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp28_ = i;
#line 817 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp28_ != NULL) {
#line 817 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp27_ = TRUE;
#line 4823 "aggregation.c"
			} else {
				gboolean _tmp29_ = FALSE;
#line 817 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp29_ = detailed;
#line 817 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp27_ = _tmp29_ == TRUE;
#line 4830 "aggregation.c"
			}
#line 817 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp30_ = _tmp27_;
#line 817 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp30_, "i != null || detailed == true");
#line 818 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp31_ = i;
#line 818 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp31_ == NULL) {
#line 820 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 820 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				continue;
#line 4844 "aggregation.c"
			}
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp33_ = i;
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp34_ = folks_individual_get_is_user (_tmp33_);
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp35_ = _tmp34_;
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp35_) {
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp32_ = TRUE;
#line 4856 "aggregation.c"
			} else {
				FolksIndividual* _tmp36_ = NULL;
				GeeSet* _tmp37_ = NULL;
				GeeSet* _tmp38_ = NULL;
				gint _tmp39_ = 0;
				gint _tmp40_ = 0;
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp36_ = i;
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp37_ = folks_individual_get_personas (_tmp36_);
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp38_ = _tmp37_;
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp39_ = gee_collection_get_size ((GeeCollection*) _tmp38_);
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp40_ = _tmp39_;
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp32_ = _tmp40_ == 1;
#line 4875 "aggregation.c"
			}
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp41_ = _tmp32_;
#line 823 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp41_, "i.is_user || i.personas.size == 1");
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 4883 "aggregation.c"
		}
#line 815 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 4887 "aggregation.c"
	}
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data6_->_ref_count_);
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return _data6_;
#line 4897 "aggregation.c"
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
#line 4906 "aggregation.c"
		AggregationTests * self;
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		self = _data6_->self;
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data6_->aggregator);
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data6_->individuals_map);
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_slice_free (Block6Data, _data6_);
#line 4918 "aggregation.c"
	}
}


static void ____lambda23_ (Block6Data* _data6_, GObject* obj) {
	AggregationTests * self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	gchar* weak_key = NULL;
	FolksIndividual* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	FolksIndividual* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	GeeHashMap* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	AggregationTestsIndividualState state = 0;
	GeeHashMap* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gpointer _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	AggregationTestsIndividualState _tmp13_ = 0;
	gboolean _tmp18_ = FALSE;
	GeeHashMap* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
#line 898 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 898 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (obj != NULL);
#line 900 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = obj;
#line 900 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	ind = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual);
#line 901 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = ind;
#line 901 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = folks_individual_get_id (_tmp1_);
#line 901 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = _tmp2_;
#line 901 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp4_ = ind;
#line 901 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp5_ = g_strdup_printf ("%s:%p", _tmp3_, _tmp4_);
#line 901 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	weak_key = _tmp5_;
#line 903 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp6_ = _data6_->individuals_map;
#line 903 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp7_ = weak_key;
#line 903 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp8_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp6_, _tmp7_);
#line 903 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp8_ == TRUE, "individuals_map.has_key (weak_key) == true");
#line 904 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp9_ = _data6_->individuals_map;
#line 904 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp10_ = weak_key;
#line 904 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp11_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp9_, _tmp10_);
#line 904 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	state = (AggregationTestsIndividualState) ((gintptr) _tmp11_);
#line 905 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp13_ = state;
#line 905 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_tmp13_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED) {
#line 905 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp12_ = TRUE;
#line 4987 "aggregation.c"
	} else {
		gboolean _tmp14_ = FALSE;
		gboolean _tmp15_ = FALSE;
		gboolean _tmp17_ = FALSE;
#line 906 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp15_ = _data6_->aggregator_is_finalising;
#line 906 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_tmp15_ == TRUE) {
#line 4996 "aggregation.c"
			AggregationTestsIndividualState _tmp16_ = 0;
#line 907 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp16_ = state;
#line 907 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp14_ = _tmp16_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED;
#line 5002 "aggregation.c"
		} else {
#line 906 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp14_ = FALSE;
#line 5006 "aggregation.c"
		}
#line 906 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp17_ = _tmp14_;
#line 906 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp12_ = _tmp17_;
#line 5012 "aggregation.c"
	}
#line 905 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp18_ = _tmp12_;
#line 905 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp18_, "state == IndividualState.REMOVED ||                       (aggregator_is_finalising == true &&                           state == IndividualState.ADDED)");
#line 909 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp19_ = _data6_->individuals_map;
#line 909 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp20_ = weak_key;
#line 909 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp19_, _tmp20_, (gpointer) ((gintptr) AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED));
#line 898 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_free0 (weak_key);
#line 5026 "aggregation.c"
}


static void _____lambda23__gweak_notify (gpointer self, GObject* object) {
#line 898 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	____lambda23_ (self, object);
#line 5033 "aggregation.c"
}


static void __lambda22_ (Block6Data* _data6_, GeeSet* added, GeeSet* removed, const gchar* m, FolksPersona* a, FolksGroupDetailsChangeReason r) {
	AggregationTests * self;
#line 873 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 873 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (added != NULL);
#line 873 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (removed != NULL);
#line 5045 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = removed;
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = gee_iterable_iterator ((GeeIterable*) _tmp0_);
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp1_;
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 5058 "aggregation.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gchar* key = NULL;
			FolksIndividual* _tmp6_ = NULL;
			const gchar* _tmp7_ = NULL;
			const gchar* _tmp8_ = NULL;
			FolksIndividual* _tmp9_ = NULL;
			gchar* _tmp10_ = NULL;
			GeeHashMap* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			gboolean _tmp13_ = FALSE;
			GeeHashMap* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			gpointer _tmp16_ = NULL;
			GeeHashMap* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp2_ = _i_it;
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp3_) {
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 5086 "aggregation.c"
			}
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp4_ = _i_it;
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp5_;
#line 877 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp6_ = i;
#line 877 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp7_ = folks_individual_get_id (_tmp6_);
#line 877 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp8_ = _tmp7_;
#line 877 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp9_ = i;
#line 877 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp10_ = g_strdup_printf ("%s:%p", _tmp8_, _tmp9_);
#line 877 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			key = _tmp10_;
#line 879 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp11_ = _data6_->individuals_map;
#line 879 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp12_ = key;
#line 879 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp13_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp11_, _tmp12_);
#line 879 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp13_ == TRUE, "individuals_map.has_key (key) == true");
#line 880 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp14_ = _data6_->individuals_map;
#line 880 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp15_ = key;
#line 880 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp16_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp14_, _tmp15_);
#line 880 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (((AggregationTestsIndividualState) ((gintptr) _tmp16_)) == AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED, "individuals_map.get (key) == IndividualState.ADDED");
#line 882 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp17_ = _data6_->individuals_map;
#line 882 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp18_ = key;
#line 882 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			gee_abstract_map_set ((GeeAbstractMap*) _tmp17_, _tmp18_, (gpointer) ((gintptr) AGGREGATION_TESTS_INDIVIDUAL_STATE_REMOVED));
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_free0 (key);
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 5132 "aggregation.c"
		}
#line 875 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 5136 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp19_ = NULL;
		GeeIterator* _tmp20_ = NULL;
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp19_ = added;
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp20_ = gee_iterable_iterator ((GeeIterable*) _tmp19_);
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp20_;
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 5150 "aggregation.c"
			GeeIterator* _tmp21_ = NULL;
			gboolean _tmp22_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp23_ = NULL;
			gpointer _tmp24_ = NULL;
			gchar* key = NULL;
			FolksIndividual* _tmp25_ = NULL;
			const gchar* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
			FolksIndividual* _tmp28_ = NULL;
			gchar* _tmp29_ = NULL;
			GeeHashMap* _tmp30_ = NULL;
			const gchar* _tmp31_ = NULL;
			gboolean _tmp32_ = FALSE;
			GeeHashMap* _tmp33_ = NULL;
			const gchar* _tmp34_ = NULL;
			FolksIndividual* _tmp35_ = NULL;
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp21_ = _i_it;
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp22_ = gee_iterator_next (_tmp21_);
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp22_) {
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 5176 "aggregation.c"
			}
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp23_ = _i_it;
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp24_ = gee_iterator_get (_tmp23_);
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp24_;
#line 887 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp25_ = i;
#line 887 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp26_ = folks_individual_get_id (_tmp25_);
#line 887 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp27_ = _tmp26_;
#line 887 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp28_ = i;
#line 887 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp29_ = g_strdup_printf ("%s:%p", _tmp27_, _tmp28_);
#line 887 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			key = _tmp29_;
#line 889 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp30_ = _data6_->individuals_map;
#line 889 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp31_ = key;
#line 889 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp32_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp30_, _tmp31_);
#line 889 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp32_ == FALSE, "individuals_map.has_key (key) == false");
#line 891 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp33_ = _data6_->individuals_map;
#line 891 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp34_ = key;
#line 891 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			gee_abstract_map_set ((GeeAbstractMap*) _tmp33_, _tmp34_, (gpointer) ((gintptr) AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED));
#line 898 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp35_ = i;
#line 898 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			g_object_weak_ref ((GObject*) _tmp35_, _____lambda23__gweak_notify, _data6_);
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_free0 (key);
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 5218 "aggregation.c"
		}
#line 885 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 5222 "aggregation.c"
	}
}


static void ___lambda22__folks_individual_aggregator_individuals_changed (FolksIndividualAggregator* _sender, GeeSet* added, GeeSet* removed, const gchar* message, FolksPersona* actor, FolksGroupDetailsChangeReason reason, gpointer self) {
#line 873 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda22_ (self, added, removed, message, actor, reason);
#line 5230 "aggregation.c"
}


static void __lambda25_ (Block6Data* _data6_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 919 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 919 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 5241 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 923 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data6_->aggregator;
#line 923 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 923 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 923 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 5253 "aggregation.c"
			goto __catch5_g_error;
		}
	}
	goto __finally5;
	__catch5_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 921 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 921 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 927 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 927 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:927: Failed to prepare aggregator: %s", _tmp2_);
#line 929 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 921 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 5274 "aggregation.c"
	}
	__finally5:
#line 921 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 921 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 921 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 921 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 5285 "aggregation.c"
	}
}


static void ___lambda25__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 919 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda25_ (self, source_object, res);
#line 919 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block6_data_unref (self);
#line 5295 "aggregation.c"
}


static gboolean __lambda24_ (Block6Data* _data6_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 917 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data6_->self;
#line 919 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data6_->aggregator;
#line 919 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda25__gasync_ready_callback, block6_data_ref (_data6_));
#line 933 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 933 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 5313 "aggregation.c"
}


static gboolean ___lambda24__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda24_ (self);
#line 917 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 5322 "aggregation.c"
}


void aggregation_tests_test_linked_individual_refcounting (AggregationTests* self) {
	Block6Data* _data6_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	void* _tmp3_ = NULL;
	GeeHashMap* _tmp4_ = NULL;
	FolksIndividualAggregator* _tmp5_ = NULL;
	FolksIndividualAggregator* _tmp6_ = NULL;
	GMainLoop* _tmp7_ = NULL;
	GeeMapIterator* iter = NULL;
	GeeHashMap* _tmp8_ = NULL;
	GeeMapIterator* _tmp9_ = NULL;
	TpTestsBackend* _tmp18_ = NULL;
	void* _tmp19_ = NULL;
	KfTestBackend* _tmp20_ = NULL;
	GMainLoop* _tmp21_ = NULL;
	GeeHashMap* _tmp22_ = NULL;
	GeeMapIterator* _tmp23_ = NULL;
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data6_ = g_slice_new0 (Block6Data);
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data6_->_ref_count_ = 1;
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data6_->self = g_object_ref (self);
#line 843 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 843 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	main_loop = _tmp0_;
#line 845 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 845 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "[0]\n" "protocol=travis@example.com;olivier@example.com;" "guillaume@example.com;sjoerd@example.com\n" "[1]\n" "protocol=christian@example.com;wim@example.com;" "helen@example.com;geraldine@example.com");
#line 852 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 852 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_tests_backend_add_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend), "protocol", "me@example.com", "cm", "account");
#line 852 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	((TpfTestTestCase*) self)->account_handle = _tmp3_;
#line 867 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp4_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, AGGREGATION_TESTS_TYPE_INDIVIDUAL_STATE, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 867 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data6_->individuals_map = _tmp4_;
#line 870 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp5_ = folks_individual_aggregator_dup ();
#line 870 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data6_->aggregator = _tmp5_;
#line 871 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data6_->aggregator_is_finalising = FALSE;
#line 873 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp6_ = _data6_->aggregator;
#line 873 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp6_, "individuals-changed", (GCallback) ___lambda22__folks_individual_aggregator_individuals_changed, block6_data_ref (_data6_), (GClosureNotify) block6_data_unref, 0);
#line 917 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda24__gsource_func, block6_data_ref (_data6_), block6_data_unref);
#line 936 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp7_ = main_loop;
#line 936 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp7_, 3);
#line 940 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp8_ = _data6_->individuals_map;
#line 940 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp9_ = gee_abstract_map_map_iterator ((GeeAbstractMap*) _tmp8_);
#line 940 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	iter = _tmp9_;
#line 941 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	while (TRUE) {
#line 5396 "aggregation.c"
		GeeMapIterator* _tmp10_ = NULL;
		gboolean _tmp11_ = FALSE;
		AggregationTestsIndividualState state = 0;
		GeeMapIterator* _tmp12_ = NULL;
		gpointer _tmp13_ = NULL;
		gboolean _tmp14_ = FALSE;
		AggregationTestsIndividualState _tmp15_ = 0;
		gboolean _tmp17_ = FALSE;
#line 941 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp10_ = iter;
#line 941 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp11_ = gee_map_iterator_next (_tmp10_);
#line 941 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (!(_tmp11_ == TRUE)) {
#line 941 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			break;
#line 5413 "aggregation.c"
		}
#line 943 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp12_ = iter;
#line 943 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp13_ = gee_map_iterator_get_value (_tmp12_);
#line 943 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		state = (AggregationTestsIndividualState) ((gintptr) _tmp13_);
#line 944 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp15_ = state;
#line 944 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_tmp15_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_ADDED) {
#line 944 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp14_ = TRUE;
#line 5427 "aggregation.c"
		} else {
			AggregationTestsIndividualState _tmp16_ = 0;
#line 945 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp16_ = state;
#line 945 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp14_ = _tmp16_ == AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED;
#line 5434 "aggregation.c"
		}
#line 944 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp17_ = _tmp14_;
#line 944 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_vala_assert (_tmp17_, "state == IndividualState.ADDED ||                   state == IndividualState.FINALISED");
#line 5440 "aggregation.c"
	}
#line 949 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp18_ = ((TpfTestTestCase*) self)->tp_backend;
#line 949 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp19_ = ((TpfTestTestCase*) self)->account_handle;
#line 949 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tp_tests_backend_remove_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, tp_tests_backend_get_type (), TpTestsBackend), (void*) _tmp19_);
#line 950 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp20_ = ((TpfTestTestCase*) self)->kf_backend;
#line 950 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	kf_test_backend_tear_down (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, KF_TEST_TYPE_BACKEND, KfTestBackend));
#line 951 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data6_->aggregator_is_finalising = TRUE;
#line 952 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data6_->aggregator);
#line 952 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data6_->aggregator = NULL;
#line 957 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp21_ = main_loop;
#line 957 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_tmp21_, 3);
#line 961 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp22_ = _data6_->individuals_map;
#line 961 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp23_ = gee_abstract_map_map_iterator ((GeeAbstractMap*) _tmp22_);
#line 961 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (iter);
#line 961 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	iter = _tmp23_;
#line 962 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	while (TRUE) {
#line 5472 "aggregation.c"
		GeeMapIterator* _tmp24_ = NULL;
		gboolean _tmp25_ = FALSE;
		GeeMapIterator* _tmp26_ = NULL;
		gpointer _tmp27_ = NULL;
#line 962 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp24_ = iter;
#line 962 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp25_ = gee_map_iterator_next (_tmp24_);
#line 962 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (!(_tmp25_ == TRUE)) {
#line 962 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			break;
#line 5485 "aggregation.c"
		}
#line 964 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp26_ = iter;
#line 964 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp27_ = gee_map_iterator_get_value (_tmp26_);
#line 964 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_vala_assert (((AggregationTestsIndividualState) ((gintptr) _tmp27_)) == AGGREGATION_TESTS_INDIVIDUAL_STATE_FINALISED, "iter.get_value () == IndividualState.FINALISED");
#line 5493 "aggregation.c"
	}
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (iter);
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_main_loop_unref0 (main_loop);
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block6_data_unref (_data6_);
#line 841 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data6_ = NULL;
#line 5503 "aggregation.c"
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return _data7_;
#line 5512 "aggregation.c"
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 5521 "aggregation.c"
		AggregationTests * self;
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		self = _data7_->self;
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->writeable_persona);
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->aggregator);
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->individual);
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data7_->main_loop);
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_slice_free (Block7Data, _data7_);
#line 5537 "aggregation.c"
	}
}


static void __lambda26_ (Block7Data* _data7_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeMultiMap* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
#line 985 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 985 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 987 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 987 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_size (_tmp0_);
#line 987 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = _tmp1_;
#line 987 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp2_ == 1, "changes.size == 1");
#line 5559 "aggregation.c"
	{
		GeeIterator* _removed_it = NULL;
		GeeMultiMap* _tmp3_ = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeSet* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
		GeeIterator* _tmp7_ = NULL;
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp3_ = changes;
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp4_ = gee_multi_map_get_keys (_tmp3_);
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp5_ = _tmp4_;
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp7_ = _tmp6_;
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_tmp5_);
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_removed_it = _tmp7_;
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 5583 "aggregation.c"
			GeeIterator* _tmp8_ = NULL;
			gboolean _tmp9_ = FALSE;
			FolksIndividual* removed = NULL;
			GeeIterator* _tmp10_ = NULL;
			gpointer _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp8_ = _removed_it;
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_next (_tmp8_);
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp9_) {
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 5598 "aggregation.c"
			}
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp10_ = _removed_it;
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			removed = (FolksIndividual*) _tmp11_;
#line 991 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp12_ = removed;
#line 991 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp12_ == NULL, "removed == null");
#line 5610 "aggregation.c"
			{
				GeeIterator* _i_it = NULL;
				GeeMultiMap* _tmp13_ = NULL;
				FolksIndividual* _tmp14_ = NULL;
				GeeCollection* _tmp15_ = NULL;
				GeeCollection* _tmp16_ = NULL;
				GeeIterator* _tmp17_ = NULL;
				GeeIterator* _tmp18_ = NULL;
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp13_ = changes;
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp14_ = removed;
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp15_ = gee_multi_map_get (_tmp13_, _tmp14_);
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp16_ = _tmp15_;
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp18_ = _tmp17_;
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_tmp16_);
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_i_it = _tmp18_;
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 5637 "aggregation.c"
					GeeIterator* _tmp19_ = NULL;
					gboolean _tmp20_ = FALSE;
					FolksIndividual* i = NULL;
					GeeIterator* _tmp21_ = NULL;
					gpointer _tmp22_ = NULL;
					FolksIndividual* _tmp23_ = NULL;
					FolksIndividual* _tmp24_ = NULL;
					FolksIndividual* _tmp25_ = NULL;
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp19_ = _i_it;
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp20_ = gee_iterator_next (_tmp19_);
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					if (!_tmp20_) {
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						break;
#line 5654 "aggregation.c"
					}
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp21_ = _i_it;
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp22_ = gee_iterator_get (_tmp21_);
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					i = (FolksIndividual*) _tmp22_;
#line 995 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp23_ = i;
#line 995 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_vala_assert (_tmp23_ != NULL, "i != null");
#line 996 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_vala_assert (_data7_->individual == NULL, "individual == null");
#line 998 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp24_ = i;
#line 998 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp25_ = _g_object_ref0 (_tmp24_);
#line 998 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (_data7_->individual);
#line 998 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_data7_->individual = _tmp25_;
#line 999 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					g_main_loop_quit (_data7_->main_loop);
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (i);
#line 5680 "aggregation.c"
				}
#line 993 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 5684 "aggregation.c"
			}
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (removed);
#line 5688 "aggregation.c"
		}
#line 989 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_removed_it);
#line 5692 "aggregation.c"
	}
}


static void ___lambda26__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 985 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda26_ (self, changes);
#line 5700 "aggregation.c"
}


static void __lambda28_ (Block7Data* _data7_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1008 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1008 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 5711 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 1012 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data7_->aggregator;
#line 1012 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 1012 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 1012 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 5723 "aggregation.c"
			goto __catch6_g_error;
		}
	}
	goto __finally6;
	__catch6_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 1010 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1010 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1016 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 1016 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1016: Failed to prepare aggregator: %s", _tmp2_);
#line 1018 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1010 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 5744 "aggregation.c"
	}
	__finally6:
#line 1010 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1010 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1010 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1010 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 5755 "aggregation.c"
	}
}


static void ___lambda28__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1008 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda28_ (self, source_object, res);
#line 1008 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block7_data_unref (self);
#line 5765 "aggregation.c"
}


static gboolean __lambda27_ (Block7Data* _data7_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 1006 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1008 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data7_->aggregator;
#line 1008 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda28__gasync_ready_callback, block7_data_ref (_data7_));
#line 1022 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1022 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 5783 "aggregation.c"
}


static gboolean ___lambda27__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda27_ (self);
#line 1006 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 5792 "aggregation.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 1039 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	for (i = 0; i < stack_length; i++) {
#line 1039 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 1039 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			return TRUE;
#line 5804 "aggregation.c"
		}
	}
#line 1039 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return FALSE;
#line 5809 "aggregation.c"
}


static void __lambda30_ (Block7Data* _data7_, GObject* obj, GAsyncResult* res) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1048 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1048 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (res != NULL);
#line 5820 "aggregation.c"
	{
		FolksPersona* _tmp0_ = NULL;
		FolksIndividualAggregator* _tmp1_ = NULL;
		GAsyncResult* _tmp2_ = NULL;
		FolksPersona* _tmp3_ = NULL;
#line 1053 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = _data7_->aggregator;
#line 1053 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = res;
#line 1053 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp3_ = folks_individual_aggregator_ensure_individual_property_writeable_finish (_tmp1_, _tmp2_, &_inner_error_);
#line 1053 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _tmp3_;
#line 1053 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 5836 "aggregation.c"
			goto __catch7_g_error;
		}
#line 1052 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data7_->writeable_persona);
#line 1052 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_data7_->writeable_persona = _tmp0_;
#line 1055 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_main_loop_quit (_data7_->main_loop);
#line 5845 "aggregation.c"
	}
	goto __finally7;
	__catch7_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp4_ = NULL;
#line 1050 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1050 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1059 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp4_ = e1->message;
#line 1059 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1059: Failed to ensure property writeable: %s", _tmp4_);
#line 1061 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1050 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 5864 "aggregation.c"
	}
	__finally7:
#line 1050 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1050 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1050 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1050 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 5875 "aggregation.c"
	}
}


static void ___lambda30__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1047 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda30_ (self, source_object, res);
#line 1047 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block7_data_unref (self);
#line 5885 "aggregation.c"
}


static gboolean __lambda29_ (Block7Data* _data7_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 1045 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data7_->self;
#line 1047 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data7_->aggregator;
#line 1047 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_ensure_individual_property_writeable (_tmp0_, _data7_->individual, "alias", ___lambda30__gasync_ready_callback, block7_data_ref (_data7_));
#line 1065 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1065 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 5903 "aggregation.c"
}


static gboolean ___lambda29__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda29_ (self);
#line 1045 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 5912 "aggregation.c"
}


void aggregation_tests_test_ensure_individual_property_writeable_trivial (AggregationTests* self) {
	Block7Data* _data7_;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	FolksIndividualAggregator* _tmp3_ = NULL;
	FolksPersona* persona = NULL;
	FolksPersona* _tmp11_ = NULL;
	FolksPersona* _tmp12_ = NULL;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	gchar** _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
	FolksPersona* _tmp15_ = NULL;
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data7_ = g_slice_new0 (Block7Data);
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data7_->_ref_count_ = 1;
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data7_->self = g_object_ref (self);
#line 976 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 976 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data7_->main_loop = _tmp0_;
#line 978 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 978 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "[0]\n" "protocol=travis@example.com\n");
#line 981 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data7_->individual = NULL;
#line 984 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = folks_individual_aggregator_dup ();
#line 984 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data7_->aggregator = _tmp2_;
#line 985 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = _data7_->aggregator;
#line 985 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp3_, "individuals-changed-detailed", (GCallback) ___lambda26__folks_individual_aggregator_individuals_changed_detailed, block7_data_ref (_data7_), (GClosureNotify) block7_data_unref, 0);
#line 1006 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda27__gsource_func, block7_data_ref (_data7_), block7_data_unref);
#line 1025 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data7_->main_loop, 3);
#line 1028 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_data7_->individual != NULL, "individual != null");
#line 1030 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 5964 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeSet* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
#line 1031 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp4_ = folks_individual_get_personas (_data7_->individual);
#line 1031 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp5_ = _tmp4_;
#line 1031 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 1031 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_p_it = _tmp6_;
#line 1031 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 5980 "aggregation.c"
			gboolean _tmp7_ = FALSE;
			FolksPersona* p = NULL;
			gpointer _tmp8_ = NULL;
			FolksPersona* _tmp9_ = NULL;
			FolksPersona* _tmp10_ = NULL;
#line 1031 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp7_ = gee_iterator_next (_p_it);
#line 1031 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp7_) {
#line 1031 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 5992 "aggregation.c"
			}
#line 1031 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp8_ = gee_iterator_get (_p_it);
#line 1031 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp8_;
#line 1033 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp9_ = p;
#line 1033 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp10_ = _g_object_ref0 (_tmp9_);
#line 1033 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 1033 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			persona = _tmp10_;
#line 1034 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 1034 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			break;
#line 6010 "aggregation.c"
		}
#line 1031 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 6014 "aggregation.c"
	}
#line 1038 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp11_ = persona;
#line 1038 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp11_ != NULL, "persona != null");
#line 1039 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp12_ = persona;
#line 1039 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp13_ = folks_persona_get_writeable_properties (_tmp12_, &_tmp13__length1);
#line 1039 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp14_ = _tmp13_;
#line 1039 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp14__length1 = _tmp13__length1;
#line 1039 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_vala_string_array_contains (_tmp14_, _tmp14__length1, "alias"), "\"alias\" in persona.writeable_properties");
#line 1041 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data7_->writeable_persona = NULL;
#line 1045 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda29__gsource_func, block7_data_ref (_data7_), block7_data_unref);
#line 1068 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data7_->main_loop, 3);
#line 1070 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_data7_->writeable_persona != NULL, "writeable_persona != null");
#line 1071 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp15_ = persona;
#line 1071 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_data7_->writeable_persona == _tmp15_, "writeable_persona == persona");
#line 1074 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data7_->aggregator);
#line 1074 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data7_->aggregator = NULL;
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block7_data_unref (_data7_);
#line 974 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data7_ = NULL;
#line 6052 "aggregation.c"
}


static Block8Data* block8_data_ref (Block8Data* _data8_) {
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data8_->_ref_count_);
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return _data8_;
#line 6061 "aggregation.c"
}


static void block8_data_unref (void * _userdata_) {
	Block8Data* _data8_;
	_data8_ = (Block8Data*) _userdata_;
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data8_->_ref_count_)) {
#line 6070 "aggregation.c"
		AggregationTests * self;
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		self = _data8_->self;
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->writeable_persona);
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->aggregator);
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->individual);
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data8_->main_loop);
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_slice_free (Block8Data, _data8_);
#line 6086 "aggregation.c"
	}
}


static void __lambda31_ (Block8Data* _data8_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	gint _tmp19_ = 0;
#line 1100 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1100 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 1102 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 1102 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 1102 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	added = _tmp1_;
#line 1103 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 1103 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 1103 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	removed = _tmp3_;
#line 6118 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp4_ = added;
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp5_;
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6131 "aggregation.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp6_ = _i_it;
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp7_) {
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 6149 "aggregation.c"
			}
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp8_ = _i_it;
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp9_;
#line 1107 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 1107 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 1110 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp11_ = i;
#line 1110 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp12_ = folks_individual_get_id (_tmp11_);
#line 1110 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp13_ = _tmp12_;
#line 1110 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (g_strcmp0 (_tmp13_, "0e46c5e74f61908f49550d241f2a1651892a1695") == 0) {
#line 6169 "aggregation.c"
				FolksIndividual* _tmp14_ = NULL;
				FolksIndividual* _tmp15_ = NULL;
				FolksIndividual* _tmp16_ = NULL;
#line 1112 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp14_ = _data8_->individual;
#line 1112 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_vala_assert (_tmp14_ == NULL, "individual == null");
#line 1113 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp15_ = i;
#line 1113 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp16_ = _g_object_ref0 (_tmp15_);
#line 1113 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_data8_->individual);
#line 1113 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_data8_->individual = _tmp16_;
#line 1114 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1114 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 1114 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (removed);
#line 1114 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (added);
#line 1114 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				return;
#line 6195 "aggregation.c"
			}
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6199 "aggregation.c"
		}
#line 1105 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6203 "aggregation.c"
	}
#line 1118 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp17_ = removed;
#line 1118 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 1118 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp19_ = _tmp18_;
#line 1118 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp19_ == 1, "removed.size == 1");
#line 6213 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp20_ = NULL;
		GeeIterator* _tmp21_ = NULL;
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp20_ = removed;
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp21_ = gee_iterable_iterator ((GeeIterable*) _tmp20_);
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp21_;
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6226 "aggregation.c"
			GeeIterator* _tmp22_ = NULL;
			gboolean _tmp23_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp24_ = NULL;
			gpointer _tmp25_ = NULL;
			FolksIndividual* _tmp26_ = NULL;
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp22_ = _i_it;
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp23_ = gee_iterator_next (_tmp22_);
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp23_) {
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 6241 "aggregation.c"
			}
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp24_ = _i_it;
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp25_ = gee_iterator_get (_tmp24_);
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp25_;
#line 1122 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp26_ = i;
#line 1122 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp26_ == NULL, "i == null");
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6255 "aggregation.c"
		}
#line 1120 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6259 "aggregation.c"
	}
#line 1100 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 1100 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 6265 "aggregation.c"
}


static void ___lambda31__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 1099 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda31_ (self, changes);
#line 6272 "aggregation.c"
}


static void __lambda33_ (Block8Data* _data8_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1130 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1130 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 6283 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 1134 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data8_->aggregator;
#line 1134 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 1134 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 1134 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 6295 "aggregation.c"
			goto __catch8_g_error;
		}
	}
	goto __finally8;
	__catch8_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 1132 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1132 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1138 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 1138 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1138: Failed to prepare aggregator: %s", _tmp2_);
#line 1140 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1132 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 6316 "aggregation.c"
	}
	__finally8:
#line 1132 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1132 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1132 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1132 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 6327 "aggregation.c"
	}
}


static void ___lambda33__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1130 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda33_ (self, source_object, res);
#line 1130 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block8_data_unref (self);
#line 6337 "aggregation.c"
}


static gboolean __lambda32_ (Block8Data* _data8_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 1128 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1130 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data8_->aggregator;
#line 1130 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda33__gasync_ready_callback, block8_data_ref (_data8_));
#line 1144 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1144 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 6355 "aggregation.c"
}


static gboolean ___lambda32__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda32_ (self);
#line 1128 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 6364 "aggregation.c"
}


static void __lambda34_ (Block8Data* _data8_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
#line 1167 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1167 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 1169 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 1169 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 1169 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	added = _tmp1_;
#line 1170 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = changes;
#line 1170 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 1170 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	removed = _tmp3_;
#line 6392 "aggregation.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp4_ = removed;
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp5_;
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6405 "aggregation.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
			FolksIndividual* _tmp13_ = NULL;
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp6_ = _i_it;
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp7_) {
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 6423 "aggregation.c"
			}
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp8_ = _i_it;
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp9_;
#line 1174 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp10_ = i;
#line 1174 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp10_ == NULL) {
#line 1176 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1176 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				continue;
#line 6439 "aggregation.c"
			}
#line 1179 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp11_ = _data8_->individual;
#line 1179 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp11_ != NULL, "individual != null");
#line 1180 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp12_ = i;
#line 1180 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp13_ = _data8_->individual;
#line 1180 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp12_ == _tmp13_, "i == individual");
#line 1181 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (_data8_->individual);
#line 1181 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_data8_->individual = NULL;
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6457 "aggregation.c"
		}
#line 1172 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6461 "aggregation.c"
	}
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp14_ = NULL;
		GeeIterator* _tmp15_ = NULL;
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp14_ = added;
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_i_it = _tmp15_;
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6475 "aggregation.c"
			GeeIterator* _tmp16_ = NULL;
			gboolean _tmp17_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp18_ = NULL;
			gpointer _tmp19_ = NULL;
			FolksIndividual* _tmp20_ = NULL;
			gboolean got_tpf = FALSE;
			gboolean got_kf = FALSE;
			gboolean _tmp37_ = FALSE;
			gboolean _tmp38_ = FALSE;
			gboolean _tmp40_ = FALSE;
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp16_ = _i_it;
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp17_ = gee_iterator_next (_tmp16_);
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp17_) {
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 6495 "aggregation.c"
			}
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp18_ = _i_it;
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp19_ = gee_iterator_get (_tmp18_);
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			i = (FolksIndividual*) _tmp19_;
#line 1186 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp20_ = i;
#line 1186 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp20_ == NULL) {
#line 1188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1188 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				continue;
#line 6511 "aggregation.c"
			}
#line 1191 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			got_tpf = FALSE;
#line 1192 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			got_kf = FALSE;
#line 6517 "aggregation.c"
			{
				GeeIterator* _p_it = NULL;
				FolksIndividual* _tmp21_ = NULL;
				GeeSet* _tmp22_ = NULL;
				GeeSet* _tmp23_ = NULL;
				GeeIterator* _tmp24_ = NULL;
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp21_ = i;
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp22_ = folks_individual_get_personas (_tmp21_);
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp23_ = _tmp22_;
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp24_ = gee_iterable_iterator ((GeeIterable*) _tmp23_);
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_p_it = _tmp24_;
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 6536 "aggregation.c"
					GeeIterator* _tmp25_ = NULL;
					gboolean _tmp26_ = FALSE;
					FolksPersona* p = NULL;
					GeeIterator* _tmp27_ = NULL;
					gpointer _tmp28_ = NULL;
					FolksPersona* _tmp29_ = NULL;
					const gchar* _tmp30_ = NULL;
					const gchar* _tmp31_ = NULL;
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp25_ = _p_it;
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp26_ = gee_iterator_next (_tmp25_);
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					if (!_tmp26_) {
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						break;
#line 6553 "aggregation.c"
					}
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp27_ = _p_it;
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp28_ = gee_iterator_get (_tmp27_);
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					p = (FolksPersona*) _tmp28_;
#line 1199 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp29_ = p;
#line 1199 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp30_ = folks_persona_get_uid (_tmp29_);
#line 1199 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp31_ = _tmp30_;
#line 1199 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					if (g_strcmp0 (_tmp31_, "telepathy:/org/freedesktop/Telepathy/Account/cm/protocol/account:olivi" \
"er@example.com") == 0) {
#line 1201 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						got_tpf = TRUE;
#line 6571 "aggregation.c"
					} else {
						FolksPersona* _tmp32_ = NULL;
						FolksPersonaStore* _tmp33_ = NULL;
						FolksPersonaStore* _tmp34_ = NULL;
						const gchar* _tmp35_ = NULL;
						const gchar* _tmp36_ = NULL;
#line 1203 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp32_ = p;
#line 1203 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp33_ = folks_persona_get_store (_tmp32_);
#line 1203 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp34_ = _tmp33_;
#line 1203 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp35_ = folks_persona_store_get_type_id (_tmp34_);
#line 1203 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						_tmp36_ = _tmp35_;
#line 1203 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						if (g_strcmp0 (_tmp36_, "key-file") == 0) {
#line 1205 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
							got_kf = TRUE;
#line 6592 "aggregation.c"
						}
					}
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (p);
#line 6597 "aggregation.c"
				}
#line 1197 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_p_it);
#line 6601 "aggregation.c"
			}
#line 1209 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp38_ = got_tpf;
#line 1209 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp38_ == TRUE) {
#line 6607 "aggregation.c"
				gboolean _tmp39_ = FALSE;
#line 1209 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp39_ = got_kf;
#line 1209 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp37_ = _tmp39_ == TRUE;
#line 6613 "aggregation.c"
			} else {
#line 1209 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp37_ = FALSE;
#line 6617 "aggregation.c"
			}
#line 1209 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp40_ = _tmp37_;
#line 1209 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (_tmp40_) {
#line 6623 "aggregation.c"
				FolksIndividual* _tmp41_ = NULL;
				FolksIndividual* _tmp42_ = NULL;
#line 1211 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp41_ = i;
#line 1211 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp42_ = _g_object_ref0 (_tmp41_);
#line 1211 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_data8_->individual);
#line 1211 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_data8_->individual = _tmp42_;
#line 1212 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (i);
#line 1212 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 1212 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (removed);
#line 1212 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (added);
#line 1212 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				return;
#line 6644 "aggregation.c"
			}
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (i);
#line 6648 "aggregation.c"
		}
#line 1184 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_i_it);
#line 6652 "aggregation.c"
	}
#line 1167 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (removed);
#line 1167 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (added);
#line 6658 "aggregation.c"
}


static void ___lambda34__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 1167 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda34_ (self, changes);
#line 6665 "aggregation.c"
}


static void __lambda36_ (Block8Data* _data8_, GObject* obj, GAsyncResult* res) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1222 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (res != NULL);
#line 6676 "aggregation.c"
	{
		FolksPersona* _tmp0_ = NULL;
		FolksIndividualAggregator* _tmp1_ = NULL;
		GAsyncResult* _tmp2_ = NULL;
		FolksPersona* _tmp3_ = NULL;
#line 1227 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = _data8_->aggregator;
#line 1227 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = res;
#line 1227 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp3_ = folks_individual_aggregator_ensure_individual_property_writeable_finish (_tmp1_, _tmp2_, &_inner_error_);
#line 1227 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _tmp3_;
#line 1227 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 6692 "aggregation.c"
			goto __catch9_g_error;
		}
#line 1226 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data8_->writeable_persona);
#line 1226 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_data8_->writeable_persona = _tmp0_;
#line 1229 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_main_loop_quit (_data8_->main_loop);
#line 6701 "aggregation.c"
	}
	goto __finally9;
	__catch9_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp4_ = NULL;
#line 1224 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1224 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1233 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp4_ = e1->message;
#line 1233 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1233: Failed to ensure property writeable: %s", _tmp4_);
#line 1235 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1224 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 6720 "aggregation.c"
	}
	__finally9:
#line 1224 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1224 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1224 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1224 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 6731 "aggregation.c"
	}
}


static void ___lambda36__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1221 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda36_ (self, source_object, res);
#line 1221 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block8_data_unref (self);
#line 6741 "aggregation.c"
}


static gboolean __lambda35_ (Block8Data* _data8_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
#line 1219 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data8_->self;
#line 1221 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data8_->aggregator;
#line 1221 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = _data8_->individual;
#line 1221 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_ensure_individual_property_writeable (_tmp0_, _tmp1_, "im-addresses", ___lambda36__gasync_ready_callback, block8_data_ref (_data8_));
#line 1239 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1239 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 6762 "aggregation.c"
}


static gboolean ___lambda35__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda35_ (self);
#line 1219 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 6771 "aggregation.c"
}


void aggregation_tests_test_ensure_individual_property_writeable_add_persona (AggregationTests* self) {
	Block8Data* _data8_;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	TpTestsBackend* _tmp2_ = NULL;
	void* _tmp3_ = NULL;
	FolksIndividualAggregator* _tmp4_ = NULL;
	gulong individuals_changed_id = 0UL;
	FolksIndividualAggregator* _tmp5_ = NULL;
	gulong _tmp6_ = 0UL;
	FolksIndividual* _tmp7_ = NULL;
	FolksPersona* persona = NULL;
	FolksPersona* _tmp16_ = NULL;
	FolksPersona* _tmp17_ = NULL;
	gchar** _tmp18_ = NULL;
	gint _tmp18__length1 = 0;
	gchar** _tmp19_ = NULL;
	gint _tmp19__length1 = 0;
	FolksIndividualAggregator* _tmp20_ = NULL;
	FolksIndividualAggregator* _tmp21_ = NULL;
	FolksPersona* _tmp22_ = NULL;
	FolksPersona* _tmp23_ = NULL;
	FolksPersona* _tmp24_ = NULL;
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data8_ = g_slice_new0 (Block8Data);
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data8_->_ref_count_ = 1;
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data8_->self = g_object_ref (self);
#line 1089 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 1089 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data8_->main_loop = _tmp0_;
#line 1091 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 1091 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "");
#line 1092 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = ((TpfTestTestCase*) self)->tp_backend;
#line 1092 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = tp_tests_backend_add_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, tp_tests_backend_get_type (), TpTestsBackend), "protocol", "me@example.com", "cm", "account");
#line 1092 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	((TpfTestTestCase*) self)->account_handle = _tmp3_;
#line 1095 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data8_->individual = NULL;
#line 1098 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp4_ = folks_individual_aggregator_dup ();
#line 1098 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data8_->aggregator = _tmp4_;
#line 1099 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp5_ = _data8_->aggregator;
#line 1099 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp6_ = g_signal_connect_data (_tmp5_, "individuals-changed-detailed", (GCallback) ___lambda31__folks_individual_aggregator_individuals_changed_detailed, block8_data_ref (_data8_), (GClosureNotify) block8_data_unref, 0);
#line 1099 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	individuals_changed_id = _tmp6_;
#line 1128 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda32__gsource_func, block8_data_ref (_data8_), block8_data_unref);
#line 1147 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data8_->main_loop, 3);
#line 1150 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp7_ = _data8_->individual;
#line 1150 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp7_ != NULL, "individual != null");
#line 1152 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 6842 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp8_ = NULL;
		GeeSet* _tmp9_ = NULL;
		GeeSet* _tmp10_ = NULL;
		GeeIterator* _tmp11_ = NULL;
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp8_ = _data8_->individual;
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp9_ = folks_individual_get_personas (_tmp8_);
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp10_ = _tmp9_;
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp11_ = gee_iterable_iterator ((GeeIterable*) _tmp10_);
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_p_it = _tmp11_;
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 6861 "aggregation.c"
			gboolean _tmp12_ = FALSE;
			FolksPersona* p = NULL;
			gpointer _tmp13_ = NULL;
			FolksPersona* _tmp14_ = NULL;
			FolksPersona* _tmp15_ = NULL;
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp12_ = gee_iterator_next (_p_it);
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp12_) {
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 6873 "aggregation.c"
			}
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp13_ = gee_iterator_get (_p_it);
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp13_;
#line 1155 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp14_ = p;
#line 1155 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp15_ = _g_object_ref0 (_tmp14_);
#line 1155 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 1155 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			persona = _tmp15_;
#line 1156 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 1156 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			break;
#line 6891 "aggregation.c"
		}
#line 1153 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 6895 "aggregation.c"
	}
#line 1160 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp16_ = persona;
#line 1160 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp16_ != NULL, "persona != null");
#line 1161 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp17_ = persona;
#line 1161 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp18_ = folks_persona_get_writeable_properties (_tmp17_, &_tmp18__length1);
#line 1161 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp19_ = _tmp18_;
#line 1161 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp19__length1 = _tmp18__length1;
#line 1161 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (!_vala_string_array_contains (_tmp19_, _tmp19__length1, "im-addresses"), "!(\"im-addresses\" in persona.writeable_properties)");
#line 1163 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data8_->writeable_persona = NULL;
#line 1166 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp20_ = _data8_->aggregator;
#line 1166 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_handler_disconnect ((GObject*) _tmp20_, individuals_changed_id);
#line 1167 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp21_ = _data8_->aggregator;
#line 1167 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp21_, "individuals-changed-detailed", (GCallback) ___lambda34__folks_individual_aggregator_individuals_changed_detailed, block8_data_ref (_data8_), (GClosureNotify) block8_data_unref, 0);
#line 1219 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda35__gsource_func, block8_data_ref (_data8_), block8_data_unref);
#line 1242 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data8_->main_loop, 3);
#line 1244 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp22_ = _data8_->writeable_persona;
#line 1244 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp22_ != NULL, "writeable_persona != null");
#line 1245 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp23_ = _data8_->writeable_persona;
#line 1245 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp24_ = persona;
#line 1245 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp23_ != _tmp24_, "writeable_persona != persona");
#line 1248 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data8_->individual);
#line 1248 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data8_->individual = NULL;
#line 1249 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 1249 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 1250 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data8_->writeable_persona);
#line 1250 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data8_->writeable_persona = NULL;
#line 1251 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data8_->aggregator);
#line 1251 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data8_->aggregator = NULL;
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block8_data_unref (_data8_);
#line 1087 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data8_ = NULL;
#line 6957 "aggregation.c"
}


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return _data9_;
#line 6966 "aggregation.c"
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 6975 "aggregation.c"
		AggregationTests * self;
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		self = _data9_->self;
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->writeable_persona);
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->aggregator);
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->individual);
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_main_loop_unref0 (_data9_->main_loop);
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (self);
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_slice_free (Block9Data, _data9_);
#line 6991 "aggregation.c"
	}
}


static void __lambda37_ (Block9Data* _data9_, GeeMultiMap* changes) {
	AggregationTests * self;
	GeeMultiMap* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
#line 1274 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1274 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (changes != NULL);
#line 1276 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = changes;
#line 1276 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = gee_multi_map_get_size (_tmp0_);
#line 1276 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = _tmp1_;
#line 1276 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp2_ == 1, "changes.size == 1");
#line 7013 "aggregation.c"
	{
		GeeIterator* _removed_it = NULL;
		GeeMultiMap* _tmp3_ = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeSet* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
		GeeIterator* _tmp7_ = NULL;
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp3_ = changes;
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp4_ = gee_multi_map_get_keys (_tmp3_);
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp5_ = _tmp4_;
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp7_ = _tmp6_;
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_tmp5_);
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_removed_it = _tmp7_;
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 7037 "aggregation.c"
			GeeIterator* _tmp8_ = NULL;
			gboolean _tmp9_ = FALSE;
			FolksIndividual* removed = NULL;
			GeeIterator* _tmp10_ = NULL;
			gpointer _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp8_ = _removed_it;
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp9_ = gee_iterator_next (_tmp8_);
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp9_) {
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 7052 "aggregation.c"
			}
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp10_ = _removed_it;
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			removed = (FolksIndividual*) _tmp11_;
#line 1280 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp12_ = removed;
#line 1280 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_vala_assert (_tmp12_ == NULL, "removed == null");
#line 7064 "aggregation.c"
			{
				GeeIterator* _i_it = NULL;
				GeeMultiMap* _tmp13_ = NULL;
				FolksIndividual* _tmp14_ = NULL;
				GeeCollection* _tmp15_ = NULL;
				GeeCollection* _tmp16_ = NULL;
				GeeIterator* _tmp17_ = NULL;
				GeeIterator* _tmp18_ = NULL;
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp13_ = changes;
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp14_ = removed;
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp15_ = gee_multi_map_get (_tmp13_, _tmp14_);
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp16_ = _tmp15_;
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_tmp18_ = _tmp17_;
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_tmp16_);
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_i_it = _tmp18_;
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				while (TRUE) {
#line 7091 "aggregation.c"
					GeeIterator* _tmp19_ = NULL;
					gboolean _tmp20_ = FALSE;
					FolksIndividual* i = NULL;
					GeeIterator* _tmp21_ = NULL;
					gpointer _tmp22_ = NULL;
					FolksIndividual* _tmp23_ = NULL;
					FolksIndividual* _tmp24_ = NULL;
					FolksIndividual* _tmp25_ = NULL;
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp19_ = _i_it;
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp20_ = gee_iterator_next (_tmp19_);
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					if (!_tmp20_) {
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
						break;
#line 7108 "aggregation.c"
					}
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp21_ = _i_it;
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp22_ = gee_iterator_get (_tmp21_);
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					i = (FolksIndividual*) _tmp22_;
#line 1284 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp23_ = i;
#line 1284 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_vala_assert (_tmp23_ != NULL, "i != null");
#line 1285 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_vala_assert (_data9_->individual == NULL, "individual == null");
#line 1287 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp24_ = i;
#line 1287 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_tmp25_ = _g_object_ref0 (_tmp24_);
#line 1287 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (_data9_->individual);
#line 1287 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_data9_->individual = _tmp25_;
#line 1288 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					g_main_loop_quit (_data9_->main_loop);
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
					_g_object_unref0 (i);
#line 7134 "aggregation.c"
				}
#line 1282 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				_g_object_unref0 (_i_it);
#line 7138 "aggregation.c"
			}
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (removed);
#line 7142 "aggregation.c"
		}
#line 1278 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_removed_it);
#line 7146 "aggregation.c"
	}
}


static void ___lambda37__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 1274 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda37_ (self, changes);
#line 7154 "aggregation.c"
}


static void __lambda39_ (Block9Data* _data9_, GObject* s, GAsyncResult* r) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1297 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1297 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (r != NULL);
#line 7165 "aggregation.c"
	{
		FolksIndividualAggregator* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 1301 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _data9_->aggregator;
#line 1301 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = r;
#line 1301 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		folks_individual_aggregator_prepare_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 1301 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 7177 "aggregation.c"
			goto __catch10_g_error;
		}
	}
	goto __finally10;
	__catch10_g_error:
	{
		GError* e1 = NULL;
		const gchar* _tmp2_ = NULL;
#line 1299 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1299 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1305 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = e1->message;
#line 1305 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("aggregation.vala:1305: Failed to prepare aggregator: %s", _tmp2_);
#line 1307 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 1299 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 7198 "aggregation.c"
	}
	__finally10:
#line 1299 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1299 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1299 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1299 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 7209 "aggregation.c"
	}
}


static void ___lambda39__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1297 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda39_ (self, source_object, res);
#line 1297 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block9_data_unref (self);
#line 7219 "aggregation.c"
}


static gboolean __lambda38_ (Block9Data* _data9_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 1295 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1297 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data9_->aggregator;
#line 1297 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_prepare (_tmp0_, ___lambda39__gasync_ready_callback, block9_data_ref (_data9_));
#line 1311 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1311 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 7237 "aggregation.c"
}


static gboolean ___lambda38__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda38_ (self);
#line 1295 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 7246 "aggregation.c"
}


static void __lambda41_ (Block9Data* _data9_, GObject* obj, GAsyncResult* res) {
	AggregationTests * self;
	GError * _inner_error_ = NULL;
#line 1337 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1337 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (res != NULL);
#line 7257 "aggregation.c"
	{
		FolksPersona* _tmp0_ = NULL;
		FolksIndividualAggregator* _tmp1_ = NULL;
		GAsyncResult* _tmp2_ = NULL;
		FolksPersona* _tmp3_ = NULL;
#line 1342 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp1_ = _data9_->aggregator;
#line 1342 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp2_ = res;
#line 1342 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp3_ = folks_individual_aggregator_ensure_individual_property_writeable_finish (_tmp1_, _tmp2_, &_inner_error_);
#line 1342 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp0_ = _tmp3_;
#line 1342 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (_inner_error_ != NULL) {
#line 7273 "aggregation.c"
			goto __catch11_g_error;
		}
#line 1341 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_data9_->writeable_persona);
#line 1341 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_data9_->writeable_persona = _tmp0_;
#line 1343 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_assert_not_reached ();
#line 7282 "aggregation.c"
	}
	goto __finally11;
	__catch11_g_error:
	{
		GError* e1 = NULL;
#line 1339 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		e1 = _inner_error_;
#line 1339 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_inner_error_ = NULL;
#line 1348 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		if (!g_error_matches (e1, FOLKS_INDIVIDUAL_AGGREGATOR_ERROR, FOLKS_INDIVIDUAL_AGGREGATOR_ERROR_PROPERTY_NOT_WRITEABLE)) {
#line 7294 "aggregation.c"
			const gchar* _tmp4_ = NULL;
#line 1350 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp4_ = e1->message;
#line 1350 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			g_critical ("aggregation.vala:1350: Wrong error received: %s", _tmp4_);
#line 1351 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			g_assert_not_reached ();
#line 7302 "aggregation.c"
		}
#line 1354 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_main_loop_quit (_data9_->main_loop);
#line 1339 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_error_free0 (e1);
#line 7308 "aggregation.c"
	}
	__finally11:
#line 1339 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	if (_inner_error_ != NULL) {
#line 1339 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1339 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		g_clear_error (&_inner_error_);
#line 1339 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		return;
#line 7319 "aggregation.c"
	}
}


static void ___lambda41__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1336 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	__lambda41_ (self, source_object, res);
#line 1336 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block9_data_unref (self);
#line 7329 "aggregation.c"
}


static gboolean __lambda40_ (Block9Data* _data9_) {
	AggregationTests * self;
	gboolean result = FALSE;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 1334 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = _data9_->self;
#line 1336 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = _data9_->aggregator;
#line 1336 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_individual_aggregator_ensure_individual_property_writeable (_tmp0_, _data9_->individual, "is-favourite", ___lambda41__gasync_ready_callback, block9_data_ref (_data9_));
#line 1358 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = FALSE;
#line 1358 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 7347 "aggregation.c"
}


static gboolean ___lambda40__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda40_ (self);
#line 1334 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 7356 "aggregation.c"
}


void aggregation_tests_test_ensure_individual_property_writeable_failure (AggregationTests* self) {
	Block9Data* _data9_;
	GMainLoop* _tmp0_ = NULL;
	KfTestBackend* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	FolksIndividualAggregator* _tmp3_ = NULL;
	FolksPersona* persona = NULL;
	FolksPersona* _tmp11_ = NULL;
	FolksPersona* _tmp12_ = NULL;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	gchar** _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_return_if_fail (self != NULL);
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data9_ = g_slice_new0 (Block9Data);
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data9_->_ref_count_ = 1;
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data9_->self = g_object_ref (self);
#line 1265 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 1265 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data9_->main_loop = _tmp0_;
#line 1267 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp1_ = ((TpfTestTestCase*) self)->kf_backend;
#line 1267 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	kf_test_backend_set_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, KF_TEST_TYPE_BACKEND, KfTestBackend), "[0]\n" "protocol=travis@example.com\n");
#line 1270 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data9_->individual = NULL;
#line 1273 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp2_ = folks_individual_aggregator_dup ();
#line 1273 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data9_->aggregator = _tmp2_;
#line 1274 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp3_ = _data9_->aggregator;
#line 1274 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_signal_connect_data (_tmp3_, "individuals-changed-detailed", (GCallback) ___lambda37__folks_individual_aggregator_individuals_changed_detailed, block9_data_ref (_data9_), (GClosureNotify) block9_data_unref, 0);
#line 1295 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda38__gsource_func, block9_data_ref (_data9_), block9_data_unref);
#line 1314 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data9_->main_loop, 3);
#line 1317 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_data9_->individual != NULL, "individual != null");
#line 1319 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	persona = NULL;
#line 7407 "aggregation.c"
	{
		GeeIterator* _p_it = NULL;
		GeeSet* _tmp4_ = NULL;
		GeeSet* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
#line 1320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp4_ = folks_individual_get_personas (_data9_->individual);
#line 1320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp5_ = _tmp4_;
#line 1320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 1320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_p_it = _tmp6_;
#line 1320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		while (TRUE) {
#line 7423 "aggregation.c"
			gboolean _tmp7_ = FALSE;
			FolksPersona* p = NULL;
			gpointer _tmp8_ = NULL;
			FolksPersona* _tmp9_ = NULL;
			FolksPersona* _tmp10_ = NULL;
#line 1320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp7_ = gee_iterator_next (_p_it);
#line 1320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			if (!_tmp7_) {
#line 1320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
				break;
#line 7435 "aggregation.c"
			}
#line 1320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp8_ = gee_iterator_get (_p_it);
#line 1320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			p = (FolksPersona*) _tmp8_;
#line 1322 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp9_ = p;
#line 1322 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_tmp10_ = _g_object_ref0 (_tmp9_);
#line 1322 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (persona);
#line 1322 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			persona = _tmp10_;
#line 1323 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			_g_object_unref0 (p);
#line 1323 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
			break;
#line 7453 "aggregation.c"
		}
#line 1320 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
		_g_object_unref0 (_p_it);
#line 7457 "aggregation.c"
	}
#line 1327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp11_ = persona;
#line 1327 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_tmp11_ != NULL, "persona != null");
#line 1328 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp12_ = persona;
#line 1328 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp13_ = folks_persona_get_writeable_properties (_tmp12_, &_tmp13__length1);
#line 1328 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp14_ = _tmp13_;
#line 1328 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp14__length1 = _tmp13__length1;
#line 1328 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (!_vala_string_array_contains (_tmp14_, _tmp14__length1, "is-favourite"), "!(\"is-favourite\" in persona.writeable_properties)");
#line 1330 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data9_->writeable_persona = NULL;
#line 1334 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda40__gsource_func, block9_data_ref (_data9_), block9_data_unref);
#line 1361 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (_data9_->main_loop, 3);
#line 1363 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_vala_assert (_data9_->writeable_persona == NULL, "writeable_persona == null");
#line 1366 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (_data9_->aggregator);
#line 1366 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data9_->aggregator = NULL;
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (persona);
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	block9_data_unref (_data9_);
#line 1263 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_data9_ = NULL;
#line 7491 "aggregation.c"
}


static void aggregation_tests_class_init (AggregationTestsClass * klass) {
#line 24 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	aggregation_tests_parent_class = g_type_class_peek_parent (klass);
#line 24 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_type_class_add_private (klass, sizeof (AggregationTestsPrivate));
#line 24 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	TPF_TEST_TEST_CASE_CLASS (klass)->set_up_tp = aggregation_tests_real_set_up_tp;
#line 24 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	TPF_TEST_TEST_CASE_CLASS (klass)->set_up_kf = aggregation_tests_real_set_up_kf;
#line 24 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	G_OBJECT_CLASS (klass)->finalize = aggregation_tests_finalize;
#line 7506 "aggregation.c"
}


static void aggregation_tests_instance_init (AggregationTests * self) {
#line 24 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self->priv = AGGREGATION_TESTS_GET_PRIVATE (self);
#line 7513 "aggregation.c"
}


static void aggregation_tests_finalize (GObject* obj) {
	AggregationTests * self;
#line 24 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_AGGREGATION_TESTS, AggregationTests);
#line 26 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (self->priv->_default_personas);
#line 24 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	G_OBJECT_CLASS (aggregation_tests_parent_class)->finalize (obj);
#line 7525 "aggregation.c"
}


GType aggregation_tests_get_type (void) {
	static volatile gsize aggregation_tests_type_id__volatile = 0;
	if (g_once_init_enter (&aggregation_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AggregationTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) aggregation_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AggregationTests), 0, (GInstanceInitFunc) aggregation_tests_instance_init, NULL };
		GType aggregation_tests_type_id;
		aggregation_tests_type_id = g_type_register_static (TPF_TEST_TYPE_MIXED_TEST_CASE, "AggregationTests", &g_define_type_info, 0);
		g_once_init_leave (&aggregation_tests_type_id__volatile, aggregation_tests_type_id);
	}
	return aggregation_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	AggregationTests* tests = NULL;
	AggregationTests* _tmp0_ = NULL;
#line 1372 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_test_init (&args_length1, &args, NULL);
#line 1374 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_tmp0_ = aggregation_tests_new ();
#line 1374 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	tests = _tmp0_;
#line 1375 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 1376 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_test_run ();
#line 1377 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 1379 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	result = 0;
#line 1379 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	_g_object_unref0 (tests);
#line 1379 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return result;
#line 7563 "aggregation.c"
}


int main (int argc, char ** argv) {
#line 1370 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	g_type_init ();
#line 1370 "/home/treitter/collabora/folks/tests/folks/aggregation.vala"
	return _vala_main (argv, argc);
#line 7572 "aggregation.c"
}



